@@ -946,19 +946,20 @@ sub www_inviteUserSave {
         my $invitation = WebGUI::Mail::Send->create(
             $session, {
                 to      => $to,
-                from    => $email,
+                from    => $session->setting->get('companyEmail'),
+                replyTo => $email,
                 subject => $subject,
             }
         );
 
         ## No sneaky attack paths...
-        $var->{'message'} = WebGUI::HTML::html2text( WebGUI::HTML::filter($message) );
+        $var->{'message'} = WebGUI::HTML::format(WebGUI::HTML::filter($message));
 
         my $emailBody = $self->processTemplate( $var, $self->getInviteUserMessageTemplateId );
 
-        $invitation->addText($emailBody);
+        $invitation->addHtml($emailBody);
 
-        $invitation->send;
+        $invitation->queue;
 
     } ## end for my $inviteeEmail (@toList)
 
