@@ -107,13 +107,13 @@ sub appendCommonVars {
     my $self          = shift;
     my $var           = shift;
     my $session       = $self->session;
-    my $user          = $session->user;
+    my $user          = $self->getUser;
     my $pageUrl       = $session->url->page;
 
     $self->SUPER::appendCommonVars($var);
 
     $var->{'edit_profile_url'     } = $self->getUrl("module=profile;do=edit");
-    $var->{'invitations_enabled'  } = $session->user->profileField('ableToBeFriend');
+    $var->{'invitations_enabled'  } = $user->profileField('ableToBeFriend');
     $var->{'profile_category_loop'} = [];
 
     #Append the categories
@@ -285,10 +285,7 @@ This method returns the template ID for the account layout.
 
 sub getLayoutTemplateId {
     my $self    = shift;
-    my $session = $self->session;
-    my $method  = $self->method;
-    my $uid     = $self->uid;
-    return $session->setting->get("profileLayoutTemplateId") || "FJbUTvZ2nUTn65LpW6gjsA";
+    return $self->session->setting->get("profileLayoutTemplateId") || "FJbUTvZ2nUTn65LpW6gjsA";
 }
 
 #-------------------------------------------------------------------
@@ -435,8 +432,8 @@ sub www_editSave {
     unless(scalar(@{$retHash->{errors}})) {
         my $profile  = $retHash->{profile};
         my $privacy  = {};
+        $session->user->update($profile);
         foreach my $fieldName (keys %{$profile}) {
-            $session->user->profileField($fieldName,$profile->{$fieldName});
             my $privacySetting     = $session->form->get("privacy_".$fieldName);
             next unless $privacySetting;
             $privacy->{$fieldName} = $privacySetting;
@@ -475,10 +472,6 @@ sub www_view {
 
     $self->appendCommonVars($var);
 
-    #Overwrite these
-    $var->{'user_full_name'    } = $user->getWholeName;
-    $var->{'user_member_since' } = $user->dateCreated;
-    $var->{'profile_user_id'   } = $user->userId;
     $var->{'can_edit_profile'  } = $uid eq $session->user->userId;
 
     my $privacySetting = $user->profileField('publicProfile') || 'none';
