@@ -1100,6 +1100,23 @@ sub getEditForm {
 	return $tabform;
 }
 
+sub setupFormField {
+  my ($self, $tabform, $fieldName, $extraFields, $overrides) = @_;
+  my %params = %{$extraFields->{$fieldName}};
+  my $tab = delete $params{tab};
+
+  if (exists $overrides->{fields}{$fieldName}) {
+    my %overrideParams = %{$overrides->{fields}{$fieldName}};
+    my $overrideTab = delete $overrideParams{tab};
+    $tab = $overrideTab if defined $overrideTab;
+    foreach my $key (keys %overrideParams) {
+      $params{"-$key"} = $overrideParams{$key};
+    }
+  }
+
+  $tab ||= 'properties';
+  return $tabform->getTab($tab)->dynamicField(%params);
+}
 
 #-------------------------------------------------------------------
 
@@ -1298,7 +1315,6 @@ sub getIsa {
         }
         my $asset = eval { WebGUI::Asset->newPending($session, $assetId); };
         if (!$asset) {
-            warn "got an error\n";
             WebGUI::Error::ObjectNotFound->throw(id => $assetId);
         }
         return $asset;
@@ -1744,22 +1760,11 @@ sub indexContent {
 
 #-------------------------------------------------------------------
 
-=head2 isValidRssItem ( )
-
-Returns true iff this asset should be included in RSS feeds from the
-RSS From Parent asset.  If false, this asset will be ignored when
-generating feeds, even if it appears in the item list.  Defaults to
-true.
-
-=cut
-
-sub isValidRssItem { 1 }
-
-#-------------------------------------------------------------------
-
 =head2 loadModule ( $session, $className ) 
 
-Loads an asset module if it's not already in memory. This is a class method. Returns undef on failure to load, otherwise returns the classname.  Will only load classes in the WebGUI::Asset namespace.
+Loads an asset module if it's not already in memory. This is a class
+method. Returns undef on failure to load, otherwise returns the classname.
+Will only load classes in the WebGUI::Asset namespace.
 
 =cut
 
@@ -2419,7 +2424,7 @@ sub publish {
 	my $assetIds = $self->session->db->buildArrayRef("select assetId from asset where lineage like ".$self->session->db->quote($self->get("lineage").'%')." $where");
         my $idList = $self->session->db->quoteAndJoin($assetIds);
         
-	$self->session->db->write("update asset set state='published', stateChangedBy=".$self->session->db->quote($self->session->user->userId).", stateChanged=".$self->session->datetime->time()." where assetId in (".$idList.")");
+	$self->session->db->write("update asset set state='published', stateChangedBy=".$self->session->db->quote($self->session->user->userId).", stateChanged=".time()." where assetId in (".$idList.")");
 	my $cache = WebGUI::Cache->new($self->session);
         foreach my $id (@{$assetIds}) {
         	# we do the purge directly cuz it's a lot faster than instantiating all these assets
@@ -2905,6 +2910,7 @@ sub www_editSave {
             $object = $object->cloneFromDb;
         }
     }
+
     # Handle "saveAndReturn" button
     if ( $session->form->process( "saveAndReturn" ) ne "" ) {
         return $object->www_edit;
