@@ -562,6 +562,13 @@ sub makeShortcut {
         $shortcut->setOverride( $overrides );
     }
 
+    if (WebGUI::VersionTag->autoCommitWorkingIfEnabled($session, {
+        allowComments   => 1,
+        returnUrl       => $self->getUrl,
+    }) eq 'redirect') {
+        return 'redirect';
+    };
+
     return $shortcut;
 }
 
@@ -804,13 +811,13 @@ sub view {
             keyword             => $keyword,
             url_searchKeyword   
                 => $self->getGallery->getUrl(
-                    "func=search;submit=1;keywords=" . uri_escape($keyword) 
+                    "func=search;submit=1;keywords=" . uri_escape_utf8($keyword) 
                 ),
             url_searchKeywordUser
                 => $self->getGallery->getUrl(
                     "func=search;submit=1;"
                     . "userId=" . $self->get("ownerUserId") . ';'
-                    . 'keywords=' . uri_escape( $keyword ) 
+                    . 'keywords=' . uri_escape_utf8( $keyword ) 
                 ),
         };
     }
@@ -1099,5 +1106,10 @@ sub www_view {
     return "chunked";
 }
 
+sub setPrivileges {
+    my $self = shift;
+    $self->getStorageLocation->setPrivileges($self);
+}
+
 
 1; # Who knew the truth would be so obvious?
