@@ -115,7 +115,6 @@ sub applyConstraints {
     # Update the asset's size and make a thumbnail
     my $maxImageSize    = $gallery->get("imageViewSize") 
                         || $self->session->setting->get("maxImageSize");
-    my $parameters      = $self->get("parameters");
     my $storage         = $self->getStorageLocation;
     my $file            = $self->get("filename");
 
@@ -236,7 +235,7 @@ sub getExifData {
 =head2 getResolutions ( )
 
 Get an array reference of download resolutions that exist for this image. 
-Does not include the web view image or the thumbnail image.
+Does not include the web view image or the thumbnail images.
 
 =cut
 
@@ -245,7 +244,7 @@ sub getResolutions {
     my $storage     = $self->getStorageLocation;
 
     # Return a list not including the web view image.
-    return [ sort { $a <=> $b } grep { $_ ne $self->get("filename") } @{ $storage->getFiles } ];
+    return [ sort { $a cmp $b } grep { $_ ne $self->get("filename") } @{ $storage->getFiles } ];
 }
 
 #----------------------------------------------------------------------------
