@@ -597,7 +597,7 @@ sub setRatings {
         if ($ratings->{$category}) {
             $db->write("insert into MatrixListing_rating 
                 (userId, category, rating, timeStamp, listingId, ipAddress, assetId) values (?,?,?,?,?,?,?)",
-                [$session->user->userId,$category,$ratings->{$category},$session->datetime->time(),$self->getId,
+                [$session->user->userId,$category,$ratings->{$category},time(),$self->getId,
                 $session->env->get("HTTP_X_FORWARDED_FOR"),$matrixId]);
         }
         my $sql     = "from MatrixListing_rating where listingId=? and category=?";
@@ -690,26 +690,16 @@ sub view {
         $var->{productUrl_click}        .= ';revision='.$revisionDate;
     }
 
-    $self->session->style->setScript($self->session->url->extras('yui/build/yahoo/yahoo-min.js'),
+    $self->session->style->setScript($self->session->url->extras('yui/build/utilities/utilities.js'),
         {type => 'text/javascript'});
-    $self->session->style->setScript($self->session->url->extras('yui/build/dom/dom-min.js'),
-        {type => 'text/javascript'});
-    $self->session->style->setScript($self->session->url->extras('yui/build/event/event-min.js'),
-        {type => 'text/javascript'});
-    $self->session->style->setScript($self->session->url->extras('yui/build/json/json-min.js'), {type =>
-    'text/javascript'});
-    $self->session->style->setScript($self->session->url->extras('yui/build/connection/connection-min.js'),
-        {type => 'text/javascript'});
-    $self->session->style->setScript($self->session->url->extras('yui/build/get/get-min.js'), {type =>
-    'text/javascript'});
-    $self->session->style->setScript($self->session->url->extras('yui/build/element/element-beta-min.js'), {type =>
-    'text/javascript'});
     $self->session->style->setScript($self->session->url->extras('yui/build/datasource/datasource-min.js'),
-    {type => 'text/javascript'});
+        {type => 'text/javascript'});
     $self->session->style->setScript($self->session->url->extras('yui/build/datatable/datatable-min.js'),
-    {type =>'text/javascript'});
+        {type =>'text/javascript'});
     $self->session->style->setScript($self->session->url->extras('yui/build/button/button-min.js'),
-    {type =>'text/javascript'});
+        {type =>'text/javascript'});
+    $self->session->style->setScript($self->session->url->extras('yui/build/json/json-min.js'),
+        {type => 'text/javascript'});
     $self->session->style->setLink($self->session->url->extras('yui/build/datatable/assets/skins/sam/datatable.css'),
         {type =>'text/css', rel=>'stylesheet'});
 
@@ -909,7 +899,6 @@ Web facing method which is the default edit page
 
 sub www_edit {
     my $self = shift;
-    my $i18n = WebGUI::International->new($self->session, "Asset_MatrixListing");
 
     if($self->session->form->process('func') eq 'add'){
         return $self->session->privilege->noAccess() unless $self->getParent->canAddMatrixListing();
