@@ -497,16 +497,17 @@ sub getDeleteUrl {
 
 #-------------------------------------------------------------------
 
-=head2 getDirectLinkUrl ( )
+=head2 getThreadLinkUrl ( )
 
 Returns the URL for this Post, which links directly to its anchor and page.
 
 =cut
 
-sub getDirectLinkUrl {
+sub getThreadLinkUrl {
 	my $self = shift;
     my $url;
-    my $page_size = $self->getThread->getParent->get('postsPerPage');
+    my $paginator = WebGUI::Paginator->new($self->session, '', $self->getThread->getParent->get('postsPerPage'));
+    my $page_size = $paginator->{_rpp}; ##To make sure defaults are handled correctly.
     my $place     = $self->getRank+1;
     my $page      = int($place/$page_size) + 1;
     my $page_frag = 'pn='.$page;
@@ -918,7 +919,7 @@ sub insertUserPostRating {
 		[$self->getId,
 		 $self->session->user->userId,
 		 $self->session->env->getIp,
-		 $self->session->datetime->time(),
+		 time(),
 		 $rating,]
 	);
 }
@@ -1126,6 +1127,9 @@ sub processPropertiesFromFormPost {
     else {
         $self->getThread->unsubscribe;
     }
+    if ($self->canEdit && $form->process('skip_notification')) {
+        $self->setSkipNotification;
+    }
     if ($self->getThread->getParent->canEdit) {
         $form->process('isLocked') ?  $self->getThread->lock  : $self->getThread->unlock;
         $form->process('isSticky') ?  $self->getThread->stick : $self->getThread->unstick;
@@ -1157,10 +1161,9 @@ sub postProcess {
             $self->trash;
         }
     }
-	my $user = WebGUI::User->new($self->session, $self->get("ownerUserId"));
 	my $i18n = WebGUI::International->new($self->session, "Asset_Post");
 	if ($self->getThread->getParent->get("addEditStampToPosts")) {
-		$data{content} .= "<p>\n\n --- (".$i18n->get('Edited_on')." ".$self->session->datetime->epochToHuman(undef,"%z %Z [GMT%O]")." ".$i18n->get('By')." ".$user->profileField("alias").") --- \n</p>";
+		$data{content} .= "<p>\n\n --- (".$i18n->get('Edited_on')." ".$self->session->datetime->epochToHuman(undef,"%z %Z [GMT%O]")." ".$i18n->get('By')." ".$self->session->user->profileField("alias").") --- \n</p>";
 	}
 	$data{url} = $self->fixUrl($self->getThread->get("url")."/1") if ($self->isReply && $self->isNew);
 	$data{groupIdView} = $self->getThread->getParent->get("groupIdView");
@@ -1476,16 +1479,15 @@ Renders a template form for adding and editing posts.
 =cut
 
 sub www_edit {
-	my $self      = shift;
+    my $self      = shift;
     my $session   = $self->session;
     my $form      = $session->form;
     my $privilege = $session->privilege;
     my $user      = $session->user;
     my $func      = $form->process("func");
     
-	my (%var, $content, $title, $synopsis);
-	my $i18n = WebGUI::International->new($session);
-
+    my (%var, $content, $title, $synopsis);
+    my $i18n = WebGUI::International->new($session);
 
     my $className = $form->process("class","className") || $self->get('className');
 	if ($func eq "add" || ($func eq "editSave" && $form->process("assetId") eq "new")) { # new post
@@ -1691,7 +1693,12 @@ sub www_edit {
         });
     }
 	$var{'form.submit'} = WebGUI::Form::submit($session, {
-        extras=>"onclick=\"this.value='".$i18n->get(452)."'; this.form.func.value='editSave';return true;\""
+	    extras=>"onclick=\"this.value='".$i18n->get(452)."'; this.form.func.value='editSave';return true;\""
+	});
+	$var{'form.cancel'} = WebGUI::Form::button( $session, {
+	    name        => "cancel",
+	    value       => $i18n->get("cancel"),
+	    extras      => 'onclick="history.go(-1)"',
 	});
 	$var{'karmaScale.form'} = WebGUI::Form::integer($session, {
         name=>"karmaScale",
@@ -1700,7 +1707,7 @@ sub www_edit {
     });
 	$var{karmaIsEnabled} = $session->setting->get("useKarma");
 	$var{'form.preview'} = WebGUI::Form::submit($session, {
-        value=>$i18n->get("preview","Asset_Collaboration")
+	    value=>$i18n->get("preview","Asset_Collaboration")
     });
 	my $numberOfAttachments = $self->getThread->getParent->getValue("attachmentsPerPost");
 	$var{'attachment.form'} = WebGUI::Form::image($session, {
@@ -1714,6 +1721,10 @@ sub www_edit {
         name=>'contentType',
         value=>$self->getValue("contentType") || "mixed",
     });
+    $var{'skipNotification.form'} = WebGUI::Form::yesNo($session, {
+        name=>'skip_notification',
+        value=>$form->get("skip_notification",'yesNo') || 0,
+    });
     if ($session->setting->get("metaDataEnabled")
      && $self->getThread->getParent->get('enablePostMetaData')) {
         my $meta = $self->getMetaDataFields();
