@@ -19,6 +19,7 @@ use WebGUI::International;
 use WebGUI::Paginator;
 use WebGUI::SQL;
 use WebGUI::Utility;
+use POSIX qw/ceil/;
 
 our @ISA = qw(WebGUI::Asset::Post);
 
@@ -51,7 +52,7 @@ sub archive {
 		$post->setStatusArchived;
 	}
     my $cs = $self->getParent;
-    $cs->incrementThreads($cs->get("lastPostId"), $cs->get("lastPostDate"));
+    $cs->incrementThreads($cs->get("lastPostDate"), $cs->get("lastPostId"));
 }
 
 #-------------------------------------------------------------------
@@ -66,7 +67,7 @@ in the default asset, which better be a Collaboration System.
 sub canAdd {
     my $class   = shift;
     my $session = shift;
-    return $session->user->isInGroup($session->asset->get('canStartThreadGroupId'));
+    return $session->asset->isa('WebGUI::Asset::Wobject::Collaboration') && $session->asset->canStartThread;
 }
 
 #-------------------------------------------------------------------
@@ -340,15 +341,66 @@ sub getAutoCommitWorkflowId {
 
 #-------------------------------------------------------------------
 
-=head2 getDirectLinkUrl ( )
+=head2 getCSLinkUrl ( )
+
+This URL links to the page of the CS containing this thread, similar
+to the getThreadLink for the Post.  It does not contain the gateway
+for the site.
+
+=cut
+
+sub getCSLinkUrl {
+    my $self    = shift;
+    if ($self->get('status') eq 'archived') {
+        return $self->get('url');
+    }
+    my $session = $self->session;
+    my $url;
+    my $cs         = $self->getParent;
+    my $page_size  = $cs->get('threadsPerPage');
+    my $sql        =<<EOSQL;
+select lineage from asset
+left join Thread    using (assetId)
+left join assetData using (assetId)
+ where parentId=?
+   and className='WebGUI::Asset::Post::Thread'
+   and state='published'
+   and status='approved'
+   group by assetData.assetId
+   order by Thread.isSticky DESC,
+            lineage         DESC
+EOSQL
+
+    my $sth     = $session->db->read($sql, [$cs->getId]);
+    my $place   = 1;  ##1 based indexing
+    my $found   = 0;
+    my $lineage = $self->get('lineage');
+    THREAD: while (my $arrayRef = $sth->arrayRef) {
+        if ($arrayRef->[0] eq $lineage) {
+            $found = 1;
+            last THREAD;
+        }
+        ++$place;
+    }
+    $sth->finish;
+    return $self->get('url') if !$found;
+    my $page  = ceil($place/$page_size);
+    my $page_frag  = 'pn='.$page.';sortBy=lineage;sortOrder=desc';
+    $url = $session->url->append($cs->get('url'), $page_frag);
+    return $url;
+}
+
+#-------------------------------------------------------------------
+
+=head2 getThreadLinkUrl ( )
 
 Extend the base method from Post to remove the pagination query fragment
 
 =cut
 
-sub getDirectLinkUrl {
+sub getThreadLinkUrl {
 	my $self = shift;
-    my $url = $self->SUPER::getDirectLinkUrl();
+    my $url = $self->SUPER::getThreadLinkUrl();
     $url =~ s/\?pn=\d+//;
     if ($url =~ m{;revision=\d+}) {
         $url =~ s/;revision/?revision/;
