@@ -47,7 +47,7 @@ sub addRevision {
     my $newSelf = $self->SUPER::addRevision(@_);
     if ($newSelf->getRevisionCount > 1) {
         foreach my $field (qw(image1 image2 image3 brochure manual warranty)) {
-            if ($self->get($field) && $self->get($field) ne $newSelf->get($field)) {
+            if ($self->get($field)) {
                 my $newStorage = WebGUI::Storage->get($self->session,$self->get($field))->copy;
                 $newSelf->update({$field=>$newStorage->getId});
             }
@@ -94,7 +94,8 @@ sub definition {
             defaultValue=>undef,
             maxAttachments=>1,
             label=>$i18n->get(7),
-            deleteFileUrl=>$session->url->page("func=deleteFileConfirm;file=image1;filename=")
+            deleteFileUrl=>$session->url->page("func=deleteFileConfirm;file=image1;filename="),
+            persist => 1,
         },
         image2=>{
             tab => "properties",
@@ -102,7 +103,8 @@ sub definition {
             maxAttachments=>1,
             label=>$i18n->get(8),
             deleteFileUrl=>$session->url->page("func=deleteFileConfirm;file=image2;filename="),
-            defaultValue=>undef
+            defaultValue=>undef,
+            persist => 1,
         },
         image3=>{
             tab => "properties",
@@ -110,7 +112,8 @@ sub definition {
             maxAttachments=>1,
             label=>$i18n->get(9),
             deleteFileUrl=>$session->url->page("func=deleteFileConfirm;file=image3;filename="),
-            defaultValue=>undef
+            defaultValue=>undef,
+            persist => 1,
         },
         brochure=>{
             tab => "properties",
@@ -118,7 +121,8 @@ sub definition {
             maxAttachments=>1,
             label=>$i18n->get(13),
             deleteFileUrl=>$session->url->page("func=deleteFileConfirm;file=brochure;filename="),
-            defaultValue=>undef
+            defaultValue=>undef,
+            persist => 1,
         },
         manual=>{
             tab => "properties",
@@ -126,7 +130,8 @@ sub definition {
             maxAttachments=>1,
             label=>$i18n->get(14),
             deleteFileUrl=>$session->url->page("func=deleteFileConfirm;file=manual;filename="),
-            defaultValue=>undef
+            defaultValue=>undef,
+            persist => 1,
         },
         isShippingRequired => {
             tab          => "shop",
@@ -141,37 +146,50 @@ sub definition {
             maxAttachments=>1,
             label=>$i18n->get(15),
             deleteFileUrl=>$session->url->page("func=deleteFileConfirm;file=warranty;filename="),
-            defaultValue=>undef
+            defaultValue=>undef,
+            persist => 1,
         },
         variantsJSON => {
             ##Collateral data is stored as JSON in here
             autoGenerate => 0,
             defaultValue => '[]',
+            fieldType    => "textarea",
+            noFormPost   => 1,
         },
         accessoryJSON => {
             ##Collateral data is stored as JSON in here
             autoGenerate => 0,
             defaultValue => '[]',
+            fieldType    => "textarea",
+            noFormPost   => 1,
         },
         relatedJSON => {
             ##Collateral data is stored as JSON in here
             autoGenerate => 0,
             defaultValue => '[]',
+            fieldType    => "textarea",
+            noFormPost   => 1,
         },
         specificationJSON => {
             ##Collateral data is stored as JSON in here
             autoGenerate => 0,
             defaultValue => '[]',
+            fieldType    => "textarea",
+            noFormPost   => 1,
         },
         featureJSON => {
             ##Collateral data is stored as JSON in here
             autoGenerate => 0,
             defaultValue => '[]',
+            fieldType    => "textarea",
+            noFormPost   => 1,
         },
         benefitJSON => {
             ##Collateral data is stored as JSON in here
             autoGenerate => 0,
             defaultValue => '[]',
+            fieldType    => "textarea",
+            noFormPost   => 1,
         },
     );
     push(@{$definition}, {
@@ -240,6 +258,38 @@ sub duplicate {
 }
 
 
+#-------------------------------------------------------------------
+
+=head2 getAddToCartForm ( )
+
+Returns a form to add this Sku to the cart.  Used when this Sku is part of
+a shelf.  Overrode master class to add variant dropdown.
+
+=cut
+
+sub getAddToCartForm {
+    my $self    = shift;
+    my $session = $self->session;
+    my $i18n = WebGUI::International->new($session, 'Asset_Product');
+    my %variants = ();
+    tie %variants, 'Tie::IxHash';
+    COLLATERAL: foreach my $collateral ( @{ $self->getAllCollateral('variantsJSON')} ) {
+        next COLLATERAL unless $collateral->{quantity} > 0;
+        $variants{$collateral->{variantId}} = join ", ", $collateral->{shortdesc}, sprintf('%.2f',$collateral->{price});
+    }
+    return
+        WebGUI::Form::formHeader($session, {action => $self->getUrl})
+      . WebGUI::Form::hidden(    $session, {name => 'func',  value => 'buy'})
+      . WebGUI::Form::selectBox( $session, {
+                name    => 'vid',
+                options => \%variants,
+                value   => [0],
+        })
+      . WebGUI::Form::submit(    $session, {value => $i18n->get('add to cart')})
+      . WebGUI::Form::formFooter($session)
+      ;
+}
+
 #-------------------------------------------------------------------
 
 =head2 getAllCollateral ( tableName )
@@ -362,6 +412,17 @@ sub getConfiguredTitle {
 
 
 #-------------------------------------------------------------------
+
+=head2 getFileIconUrl ( $store )
+
+Return a file icon URL for file collateral.
+
+=head3 $store
+
+A WebGUI::Storage object.  The returned icon will be for the first file in the storage object.
+
+=cut
+
 sub getFileIconUrl {
     my $self = shift;
     my $store = $_[0];
@@ -369,6 +430,17 @@ sub getFileIconUrl {
 }
 
 #-------------------------------------------------------------------
+
+=head2 getFilename ( $store )
+
+Return a filename from a WebGUI::Storage object.
+
+=head3 $store
+
+The WebGUI::Storage object to look up the file.
+
+=cut
+
 sub getFilename {
     my $self = shift;
     my $store = $_[0];
@@ -382,6 +454,17 @@ sub getFilename {
 }
 
 #-------------------------------------------------------------------
+
+=head2 getFileUrl ( $store )
+
+Return a URL for file collateral.
+
+=head3 $store
+
+A WebGUI::Storage object.  The returned URL will be for the first file in the storage object.
+
+=cut
+
 sub getFileUrl {
     my $self = shift;
     my $store = $_[0];
@@ -682,12 +765,19 @@ sub prepareView {
 
 
 #-------------------------------------------------------------------
+
+=head2 purge 
+
+Extend the base class to handle all file collateral.
+
+=cut
+
 sub purge {
     my $self = shift;
-    my $sth = $self->session->db->read("select image1, image2, image3, brochure, manual, warranty from Product where assetId=".$self->session->db->quote($self->getId));
+    my $sth = $self->session->db->read("select image1, image2, image3, brochure, manual, warranty from Product where assetId=?", [$self->getId]);
     while (my @array = $sth->array) {
-        foreach my $id (@array){
-            next if ($id eq "");
+        ID: foreach my $id (@array){
+            next ID if ($id eq "");
             WebGUI::Storage->get($self->session,$id)->delete; 
         }
     }
@@ -699,7 +789,7 @@ sub purge {
 
 =head2 purgeCache ( )
 
-See WebGUI::Asset::purgeCache() for details.
+Extends the base class to handle cleaning up the cache for this asset.
 
 =cut
 
@@ -713,7 +803,7 @@ sub purgeCache {
 
 =head2 purgeRevision ( )
 
-See WebGUI::Asset::purgeRevision() for details.
+Extend the base method to handle deleting file collateral.
 
 =cut
 
@@ -806,6 +896,14 @@ sub setCollateral {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_addAccessory 
+
+Builds a form that lists other Products that could be accessories for this one, and allows
+the user to select them.
+
+=cut
+
 sub www_addAccessory {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -853,6 +951,13 @@ sub www_addAccessory {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_addAccessorySave 
+
+Process the addAccessory form.
+
+=cut
+
 sub www_addAccessorySave {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -872,6 +977,13 @@ sub www_addAccessorySave {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_addRelated 
+
+Provides a form for the user to pick Products related to this one.
+
+=cut
+
 sub www_addRelated {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -920,6 +1032,13 @@ sub www_addRelated {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_addRelatedSave 
+
+Process the addRelated form.
+
+=cut
+
 sub www_addRelatedSave {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -974,6 +1093,13 @@ sub www_deleteAccessoryConfirm {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_deleteBenefitConfirm 
+
+Delete a benefit from the Product, given the form variable C<bid>.
+
+=cut
+
 sub www_deleteBenefitConfirm {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -982,6 +1108,13 @@ sub www_deleteBenefitConfirm {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_deleteFeatureConfirm 
+
+Delete a feature from the Product, given the form variable C<fid>.
+
+=cut
+
 sub www_deleteFeatureConfirm {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -990,6 +1123,13 @@ sub www_deleteFeatureConfirm {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_deleteFileConfirm 
+
+Delete a piece of file collateral, as given by the form variable C<file>.
+
+=cut
+
 sub www_deleteFileConfirm {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -1003,6 +1143,13 @@ sub www_deleteFileConfirm {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_deleteRelatedConfirm 
+
+Remove a Product from the list of related products, as given by the form variable C<rid>.
+
+=cut
+
 sub www_deleteRelatedConfirm {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -1011,6 +1158,13 @@ sub www_deleteRelatedConfirm {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_deleteVariantConfirm 
+
+Remove a variant from this Product, as given by the form variable C<vid>.
+
+=cut
+
 sub www_deleteVariantConfirm {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -1019,6 +1173,13 @@ sub www_deleteVariantConfirm {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_deleteSpecificationConfirm 
+
+Remove a specification from this Product, as given by the form variable C<sid>.
+
+=cut
+
 sub www_deleteSpecificationConfirm {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -1028,6 +1189,13 @@ sub www_deleteSpecificationConfirm {
 
 
 #-------------------------------------------------------------------
+
+=head2 www_editBenefit 
+
+Form to edit, or add benefits to this Product.
+
+=cut
+
 sub www_editBenefit {
     my $self = shift;
     my $bid = shift || $self->session->form->process('bid');
@@ -1059,6 +1227,13 @@ sub www_editBenefit {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_editBenefitSave 
+
+Process the editBenefit form.
+
+=cut
+
 sub www_editBenefitSave {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -1077,6 +1252,13 @@ sub www_editBenefitSave {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_editFeature 
+
+Form to add or edit features to thie Product.
+
+=cut
+
 sub www_editFeature {
     my $self = shift;
     my $fid = shift || $self->session->form->process('fid');
@@ -1108,6 +1290,13 @@ sub www_editFeature {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_editFeatureSave 
+
+Process the editFeature form.
+
+=cut
+
 sub www_editFeatureSave {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -1126,6 +1315,13 @@ sub www_editFeatureSave {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_editSpecification 
+
+Form to add or edit a specification.
+
+=cut
+
 sub www_editSpecification {
     my $self = shift;
     my $sid = shift || $self->session->form->process('sid');
@@ -1171,6 +1367,13 @@ sub www_editSpecification {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_editSpecificationSave 
+
+Process the editSpecification form.
+
+=cut
+
 sub www_editSpecificationSave {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -1192,6 +1395,13 @@ sub www_editSpecificationSave {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_editVariant 
+
+Form to add or edit a variant.
+
+=cut
+
 sub www_editVariant {
     my $self = shift;
     my $vid  = shift || $self->session->form->process("vid");
@@ -1248,6 +1458,13 @@ sub www_editVariant {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_editVariantSave 
+
+Process the editVariant form.
+
+=cut
+
 sub www_editVariantSave {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -1271,6 +1488,13 @@ sub www_editVariantSave {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_moveAccessoryDown 
+
+Move an accessory, given by C<aid>, down one place.
+
+=cut
+
 sub www_moveAccessoryDown {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -1279,6 +1503,13 @@ sub www_moveAccessoryDown {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_moveAccessoryUp 
+
+Move an accessory, given by C<aid>, up one place.
+
+=cut
+
 sub www_moveAccessoryUp {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -1287,6 +1518,13 @@ sub www_moveAccessoryUp {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_moveBenefitDown 
+
+Move an benefit, given by C<bid>, down one place.
+
+=cut
+
 sub www_moveBenefitDown {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -1295,6 +1533,13 @@ sub www_moveBenefitDown {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_moveBenefitUp 
+
+Move an benefit, given by C<bid>, up one place.
+
+=cut
+
 sub www_moveBenefitUp {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -1303,6 +1548,13 @@ sub www_moveBenefitUp {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_moveFeatureDown 
+
+Move an feature, given by C<fid>, down one place.
+
+=cut
+
 sub www_moveFeatureDown {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -1311,6 +1563,13 @@ sub www_moveFeatureDown {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_moveFeatureUp 
+
+Move an feature, given by C<fid>, up one place.
+
+=cut
+
 sub www_moveFeatureUp {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -1319,6 +1578,13 @@ sub www_moveFeatureUp {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_moveRelatedDown 
+
+Move a related asset, given by C<rid>, down one place.
+
+=cut
+
 sub www_moveRelatedDown {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -1327,6 +1593,13 @@ sub www_moveRelatedDown {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_moveRelatedUp 
+
+Move a related asset, given by C<rid>, up one place.
+
+=cut
+
 sub www_moveRelatedUp {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -1335,6 +1608,13 @@ sub www_moveRelatedUp {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_moveSpecificationDown 
+
+Move an specification, given by C<sid>, down one place.
+
+=cut
+
 sub www_moveSpecificationDown {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -1343,6 +1623,13 @@ sub www_moveSpecificationDown {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_moveSpecificationUp 
+
+Move an specification, given by C<sid>, up one place.
+
+=cut
+
 sub www_moveSpecificationUp {
     my $self = shift;   
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -1351,6 +1638,13 @@ sub www_moveSpecificationUp {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_moveVariantDown 
+
+Move an variant, given by C<vid>, down one place.
+
+=cut
+
 sub www_moveVariantDown {
     my $self = shift;
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -1359,6 +1653,13 @@ sub www_moveVariantDown {
 }
 
 #-------------------------------------------------------------------
+
+=head2 www_moveVariantUp 
+
+Move an variant, given by C<vid>, up one place.
+
+=cut
+
 sub www_moveVariantUp {
     my $self = shift;   
     return $self->session->privilege->insufficient() unless ($self->canEdit);
@@ -1367,13 +1668,22 @@ sub www_moveVariantUp {
 }
 
 #-------------------------------------------------------------------
+
+=head2 view 
+
+Render the view screen for the Product, with variants, specification, related products,
+file collateral, and everything else.
+
+=cut
+
 sub view {
     my $self = shift;
     my $error = shift;
     my $session = $self->session;
     if (!$session->var->isAdminOn && $self->get("cacheTimeout") > 10){
-        my $out = WebGUI::Cache->new($self->session,"view_".$self->getId)->get;
-        return $out if $out;
+        my $cache = $self->getCache;
+        my $out   = $cache->get if defined $cache;
+		return $out if $out;
     }
     my (%data, $segment, %var, @featureloop, @benefitloop, @specificationloop, @accessoryloop, @relatedloop);
     tie %data, 'Tie::CPHash';
@@ -1389,23 +1699,29 @@ sub view {
     my $i18n = WebGUI::International->new($session,'Asset_Product');
     if ($brochure) {
         my $file = WebGUI::Storage->get($session,$brochure);
-        $var{"brochure_icon"}  = $self->getFileIconUrl($file);
-        $var{"brochure_label"} = $i18n->get(13);
-        $var{"brochure_URL"}   = $self->getFileUrl($file);
+        if ($self->getFilename($file)) {
+            $var{"brochure_icon"}  = $self->getFileIconUrl($file);
+            $var{"brochure_label"} = $i18n->get(13);
+            $var{"brochure_URL"}   = $self->getFileUrl($file);
+        }
     }
     #---manual
     if ($manual) {
         my $file = WebGUI::Storage->get($session,$manual);
-        $var{"manual_icon"}  = $self->getFileIconUrl($file);
-        $var{"manual_label"} = $i18n->get(14);
-        $var{"manual_URL"}   = $self->getFileUrl($file);
+        if ($self->getFilename($file)) {
+            $var{"manual_icon"}  = $self->getFileIconUrl($file);
+            $var{"manual_label"} = $i18n->get(14);
+            $var{"manual_URL"}   = $self->getFileUrl($file);
+        }
     }
     #---warranty
     if ($warranty) {
         my $file = WebGUI::Storage->get($session,$warranty);
-        $var{"warranty_icon"}  = $self->getFileIconUrl($file);
-        $var{"warranty_label"} = $i18n->get(15);
-        $var{"warranty_URL"}   = $self->getFileUrl($file);
+        if ($self->getFilename($file)) {
+            $var{"warranty_icon"}  = $self->getFileIconUrl($file);
+            $var{"warranty_label"} = $i18n->get(15);
+            $var{"warranty_URL"}   = $self->getFileUrl($file);
+        }
     }
     #---image1
     if ($image1) {
@@ -1578,7 +1894,7 @@ sub view {
 
 =head2 www_view ( )
 
-See WebGUI::Asset::Sku::www_view() for details.
+Extend the base method to handle caching.
 
 =cut
 
