@@ -189,6 +189,7 @@ sub duplicate {
 	my $self = shift;
 	my $newTemplate = $self->SUPER::duplicate;
     $newTemplate->update({isDefault => 0});
+    $newTemplate->addAttachments($self->getAttachments);
     return $newTemplate;
 }
 
@@ -372,12 +373,12 @@ sub getEditForm {
 	);
 
 	my ($style, $url) = $self->session->quick(qw(style url));
-	$style->setScript($url->extras('yui/build/yahoo/yahoo-min.js'),     {type => 'text/javascript'});
-	$style->setScript($url->extras('yui/build/json/json-min.js'),       {type => 'text/javascript'});
-	$style->setScript($url->extras('yui/build/dom/dom-min.js'),         {type => 'text/javascript'});
-	$style->setScript($url->extras('yui/build/event/event-min.js'),     {type => 'text/javascript'});
-	$style->setScript($url->extras('yui/build/connect/connect-min.js'), {type => 'text/javascript'});
-	$style->setScript($url->extras('yui-webgui/build/i18n/i18n.js'),    {type => 'text/javascript'});
+	$style->setScript($url->extras('yui/build/yahoo/yahoo-min.js'),           {type => 'text/javascript'});
+	$style->setScript($url->extras('yui/build/json/json-min.js'),             {type => 'text/javascript'});
+	$style->setScript($url->extras('yui/build/dom/dom-min.js'),               {type => 'text/javascript'});
+	$style->setScript($url->extras('yui/build/event/event-min.js'),           {type => 'text/javascript'});
+	$style->setScript($url->extras('yui/build/connection/connection-min.js'), {type => 'text/javascript'});
+	$style->setScript($url->extras('yui-webgui/build/i18n/i18n.js'),          {type => 'text/javascript'});
 
 	pop(@headers);
 	my $scriptUrl = $url->extras('templateAttachments.js');
@@ -509,7 +510,6 @@ sub packTemplate {
     my $packed  = $template;
     HTML::Packer::minify( \$packed, {
         remove_comments     => 1,
-        remove_newlines     => 1,
         do_javascript       => "shrink",
         do_stylesheet       => "minify",
     } );
