@@ -12,7 +12,11 @@ package WebGUI::Asset::WikiPage;
 
 use strict;
 use Class::C3;
-use base qw(WebGUI::AssetAspect::Comments WebGUI::Asset);
+use base qw(
+    WebGUI::AssetAspect::Subscribable
+    WebGUI::AssetAspect::Comments 
+    WebGUI::Asset
+);
 use Tie::IxHash;
 use WebGUI::International;
 use WebGUI::Utility;
@@ -121,6 +125,11 @@ sub definition {
 			defaultValue => '',
 			noFormPost => 1,
 			},
+                isFeatured => {
+                    fieldType       => "yesNo",
+                    defaultValue    => 0,
+                    noFormPost      => 1,
+                },
 	    );
 
 	push @$definition,
@@ -201,6 +210,7 @@ sub getEditForm {
 		formContent => WebGUI::Form::HTMLArea($session, { name => 'content', richEditId => $wiki->get('richEditor'), value => $self->get('content') }) ,
 		formSubmit => WebGUI::Form::submit($session, { value => 'Save' }),
 		formProtect => WebGUI::Form::yesNo($session, { name => "isProtected", value=>$self->getValue("isProtected")}),
+                formFeatured => WebGUI::Form::yesNo( $session, { name => 'isFeatured', value=>$self->getValue('isFeatured')}),
         formKeywords => WebGUI::Form::keywords($session, {
             name    => "keywords",
             value   => WebGUI::Keyword->new($session)->getKeywordsForAsset({asset=>$self}),
@@ -236,6 +246,75 @@ sub getEditForm {
 
 #-------------------------------------------------------------------
 
+=head2 getSubscriptionTemplate ( )
+
+=cut
+
+sub getSubscriptionTemplate { 
+    my ( $self ) = @_;
+    return $self->getParent->getSubscriptionTemplate;
+}
+
+#-------------------------------------------------------------------
+
+=head2 getTemplateVars ( )
+
+Get the common template vars for this asset
+
+=cut
+
+sub getTemplateVars {
+    my ( $self ) = @_;
+    my $i18n        = WebGUI::International->new($self->session, "Asset_WikiPage");
+    my $wiki        = $self->getWiki;
+    my $owner       = WebGUI::User->new( $self->session, $self->get('ownerUserId') );
+    my $keywords    = WebGUI::Keyword->new($self->session)->getKeywordsForAsset({
+        asset       => $self,
+        asArrayRef  => 1,
+    });
+    my @keywordsLoop = ();
+    foreach my $word (@{$keywords}) {
+        push @keywordsLoop, {
+            keyword => $word,
+            url     => $wiki->getUrl("func=byKeyword;keyword=".$word),
+        };
+    }
+    my $var = {
+        %{ $self->get },
+        url                 => $self->getUrl,
+        keywordsLoop        => \@keywordsLoop,
+        viewLabel           => $i18n->get("viewLabel"),
+        editLabel           => $i18n->get("editLabel"),
+        historyLabel        => $i18n->get("historyLabel"),
+        wikiHomeLabel       => $i18n->get("wikiHomeLabel", "Asset_WikiMaster"),
+        searchLabel         => $i18n->get("searchLabel", "Asset_WikiMaster"),	
+        searchUrl           => $wiki->getUrl("func=search"),
+        recentChangesUrl    => $wiki->getUrl("func=recentChanges"),
+        recentChangesLabel  => $i18n->get("recentChangesLabel", "Asset_WikiMaster"),
+        mostPopularUrl      => $wiki->getUrl("func=mostPopular"),
+        mostPopularLabel    => $i18n->get("mostPopularLabel", "Asset_WikiMaster"),
+        wikiHomeUrl         => $wiki->getUrl,
+        historyUrl          => $self->getUrl("func=getHistory"),
+        editContent         => $self->getEditForm,
+        allowsAttachments   => $wiki->get("allowAttachments"),
+        comments	        => $self->getFormattedComments(),
+        canEdit             => $self->canEdit,
+        canAdminister       => $wiki->canAdminister,
+		isProtected         => $self->isProtected,
+        content             => $wiki->autolinkHtml(
+            $self->scrubContent,
+            {skipTitles => [$self->get('title')]},
+        ),	
+        isSubscribed        => $self->isSubscribed,
+        subscribeUrl        => $self->getSubscribeUrl,
+        unsubscribeUrl      => $self->getUnsubscribeUrl,
+        owner               => $owner->get('alias'),
+    };
+    return $var;
+}
+
+#-------------------------------------------------------------------
+
 =head2 getWiki 
 
 Returns an object referring to the wiki that contains this page.  If it is not a WikiMaster,
@@ -328,12 +407,13 @@ sub processPropertiesFromFormPost {
     my $properties = {
         groupIdView 	=> $wiki->get('groupIdView'),
         groupIdEdit 	=> $wiki->get('groupToAdminister'),
-        actionTakenBy 	=> $session->user->userId,
+        actionTakenBy 	=> $self->session->user->userId,
         actionTaken 	=> $actionTaken,
     };
 
     if ($wiki->canAdminister) {
         $properties->{isProtected} = $session->form->get("isProtected");
+        $properties->{isFeatured}  = $session->form->get("isFeatured");
     }
 
 	$self->update($properties);
@@ -439,44 +519,7 @@ Renders this asset.
 
 sub view {
 	my $self = shift;
-	my $i18n = WebGUI::International->new($self->session, "Asset_WikiPage");
-    my $keywords = WebGUI::Keyword->new($self->session)->getKeywordsForAsset({
-        asset=>$self,
-        asArrayRef=>1,
-        });
-    my $wiki = $self->getWiki;
-    my @keywordsLoop = ();
-    foreach my $word (@{$keywords}) {
-        push(@keywordsLoop, {
-            keyword=>$word,
-            url=>$wiki->getUrl("func=byKeyword;keyword=".$word),
-            });
-    }
-	my $var = {
-        keywordsLoop        => \@keywordsLoop,
-		viewLabel           => $i18n->get("viewLabel"),
-		editLabel           => $i18n->get("editLabel"),
-		historyLabel        => $i18n->get("historyLabel"),
-		wikiHomeLabel       => $i18n->get("wikiHomeLabel", "Asset_WikiMaster"),
-		searchLabel         => $i18n->get("searchLabel", "Asset_WikiMaster"),	
-		searchUrl           => $self->getParent->getUrl("func=search"),
-		recentChangesUrl    => $self->getParent->getUrl("func=recentChanges"),
-		recentChangesLabel  => $i18n->get("recentChangesLabel", "Asset_WikiMaster"),
-		mostPopularUrl      => $self->getParent->getUrl("func=mostPopular"),
-		mostPopularLabel    => $i18n->get("mostPopularLabel", "Asset_WikiMaster"),
-		wikiHomeUrl         => $self->getParent->getUrl,
-		historyUrl          => $self->getUrl("func=getHistory"),
-		editContent         => $self->getEditForm,
-        allowsAttachments   => $self->getWiki->get("allowAttachments"),
-		comments			=> $self->getFormattedComments(),
-        canEdit             => $self->canEdit,
-		isProtected         => $self->isProtected,
-		content             => $self->getWiki->autolinkHtml(
-            $self->scrubContent,
-            {skipTitles => [$self->get('title')]},
-        ),	
-		};
-	return $self->processTemplate($var, $self->getWiki->get("pageTemplateId"));
+	return $self->processTemplate($self->getTemplateVars, $self->getWiki->get("pageTemplateId"));
 }
 
 #-------------------------------------------------------------------
@@ -542,6 +585,36 @@ sub www_getHistory {
 
 #-------------------------------------------------------------------
 
+=head2 www_purgeRevision
+
+Override the main method to change which group is allowed to purge revisions for WikiPages.  Only
+members who can administer the parent wiki (canAdminister) can purge revisions.
+
+=cut
+
+sub www_purgeRevision {
+	my $self    = shift;
+	my $session = $self->session;
+	return $session->privilege->insufficient() unless $self->getWiki->canAdminister;
+	my $revisionDate = $session->form->process("revisionDate");
+	return undef unless $revisionDate;
+	my $asset = WebGUI::Asset->new($session, $self->getId, $self->get("className"), $revisionDate);
+	return undef if ($asset->get('revisionDate') != $revisionDate);
+	my $parent = $asset->getParent;
+	$asset->purgeRevision;
+	if ($session->form->process("proceed") eq "manageRevisionsInTag") {
+		my $working = (defined $self) ? $self : $parent;
+		$session->http->setRedirect($working->getUrl("op=manageRevisionsInTag"));
+		return undef;
+	}
+	unless (defined $self) {
+		return $parent->www_view;
+	}
+	return $self->www_manageRevisions;
+}
+
+#-------------------------------------------------------------------
+
 =head2 www_restoreWikiPage 
 
 Publishes a wiki page that has been put into the trash or the clipboard.
