@@ -298,27 +298,6 @@ sub definition {
 
 #----------------------------------------------------------------------------
 
-=head2 addChild ( properties [, more ] )
-
-Only allows Events to be added as a child of this asset.
-
-=cut
-
-sub addChild {
-    my $self        = shift;
-    my $properties  = shift;
-    my @other       = @_;
-
-    if ($properties->{className} ne "WebGUI::Asset::Event") {
-        $self->session->errorHandler->security("add a ".$properties->{className}." to a ".$self->get("className"));
-        return undef;
-    }
-
-    return $self->SUPER::addChild($properties, @other);
-}
-
-#----------------------------------------------------------------------------
-
 =head2 addFeed ( $feedParams )
 
 Adds a new Feed to this calendar.  This is a wrapper around WebGUI::JSONCollateral's setJSONCollateral
@@ -786,7 +765,7 @@ sub getEventsIn {
                     && Event.endTime   IS NULL 
                     && 
                         !(
-                            Event.startDate > '$endDate' 
+                            Event.startDate > SUBDATE('$endDate', INTERVAL 1 DAY)
                          || Event.endDate   < '$startDate'
                         )
                 ) 
@@ -811,7 +790,7 @@ sub getEventsIn {
     my $orderby = join ',', @order_priority;
 
     my $events 
-        = $self->getLineage(["descendants"], {
+        = $self->getLineage(["children"], {
             returnObjects       => 1,
             includeOnlyClasses  => ['WebGUI::Asset::Event'],
             joinClass           => 'WebGUI::Asset::Event',
@@ -1464,8 +1443,8 @@ sub viewMonth {
     }
 
     # Day names
-    my @dayNames    = @{$dt->locale->day_names}[6,0..5]; # Put sunday first
-    my @dayAbbrs    = @{$dt->locale->day_abbreviations}[6,0..5];
+    my @dayNames    = @{$dt->locale->day_format_wide}[6,0..5]; # Put sunday first
+    my @dayAbbrs    = @{$dt->locale->day_format_abbreviated}[6,0..5];
     # Take from FirstDOW to the end and put it on the beginning
     unshift @dayNames,splice(@dayNames,$first_dow);
     unshift @dayAbbrs,splice(@dayAbbrs,$first_dow);
@@ -2120,6 +2099,7 @@ sub www_search {
     $var->{"form.header"}    
         = WebGUI::Form::formHeader($session, {
             action      => $self->getUrl,
+            method      => 'GET',
         })
         . WebGUI::Form::hidden($self->session, {
             name        => "func",
