@@ -62,26 +62,6 @@ sub _visitorCacheOk {
 		&& !$self->session->form->process('sortBy'));
 }
 
-#-------------------------------------------------------------------
-
-=head2 addChild 
-
-Extend the base method to allow only Threads as children.
-
-=cut
-
-sub addChild {
-	my $self = shift;
-	my $properties = shift;
-	my @other = @_;
-	if ($properties->{className} ne "WebGUI::Asset::Post::Thread") {
-		$self->session->errorHandler->security("add a ".$properties->{className}." to a ".$self->get("className"));
-		return undef;
-	}
-	return $self->next::method($properties, @other);
-}
-
-
 #-------------------------------------------------------------------
 
 =head2 appendPostListTemplateVars ($var, $p)
@@ -130,7 +110,7 @@ sub appendPostListTemplateVars {
 			if ($self->get("displayLastReply")) {
 				my $lastPost = $post->getLastPost();
 				%lastReply = (
-					"lastReply.url"                 => $lastPost->getDirectLinkUrl,
+					"lastReply.url"                 => $lastPost->getThreadLinkUrl,
                     "lastReply.title"               => $lastPost->get("title"),
                     "lastReply.user.isVisitor"      => $lastPost->get("ownerUserId") eq "1",
                     "lastReply.username"            => $lastPost->get("username"),
@@ -145,7 +125,7 @@ sub appendPostListTemplateVars {
 		my %postVars = (
 			%{$post->get},
             "id"                    => $post->getId,
-            "url"                   => $post->getDirectLinkUrl,
+            "url"                   => $post->getThreadLinkUrl,
 			rating_loop             => \@rating_loop,
 			"content"               => $post->formatContent,
             "status"                => $post->getStatus,
@@ -932,7 +912,8 @@ sub definition {
 
 =head2 duplicate 
 
-Extend the base method to handle making a subscription group for the new CS.
+Extend the base method to handle making a subscription group for the new CS, and
+to build a new Cron job.  It also recalculates the number of threads and replies.
 
 =cut
 
@@ -949,8 +930,24 @@ sub duplicate {
             parameters=>$self->getId,
             workflowId=>"csworkflow000000000001"
     });
-    $self->update({getMailCronId=>$newCron->getId});
-	return $newAsset;
+    $newAsset->update({getMailCronId=>$newCron->getId});
+    $newAsset->incrementReplies('','');
+    return $newAsset;
+}
+
+#-------------------------------------------------------------------
+
+=head2 duplicateBranch.
+
+Extend the base method to recalculate the number of threads and replies.
+
+=cut
+
+sub duplicateBranch {
+    my $self = shift;
+    my $newAsset = $self->next::method(@_);
+    $newAsset->incrementReplies('','');
+    return $newAsset;
 }
 
 #-------------------------------------------------------------------
@@ -1142,62 +1139,75 @@ Collaboration System
 =cut
 
 sub getThreadsPaginator {
-    my $self        = shift;
-	
-    my $scratchSortBy = $self->getId."_sortBy";
-	my $scratchSortOrder = $self->getId."_sortDir";
-	my $sortBy = $self->session->form->process("sortBy") || $self->session->scratch->get($scratchSortBy) || $self->get("sortBy");
-    my $sortOrder = $self->session->scratch->get($scratchSortOrder) || $self->get("sortOrder");
-	if ($sortBy ne $self->session->scratch->get($scratchSortBy) && $self->session->form->process("func") ne "editSave") {
-		$self->session->scratch->set($scratchSortBy,$self->session->form->process("sortBy"));
-        $self->session->scratch->set($scratchSortOrder, $sortOrder);
-	} elsif ($self->session->form->process("sortBy") && $self->session->form->process("func") ne "editSave") {
-                if ($sortOrder eq "asc") {
-                        $sortOrder = "desc";
-                } else {
-                        $sortOrder = "asc";
-                }
-                $self->session->scratch->set($scratchSortOrder, $sortOrder);
-	}
-	$sortBy ||= "assetData.revisionDate";
-	$sortOrder ||= "desc";
-    # Sort by the thread rating instead of the post rating.  other places don't care about threads.
-    if ($sortBy eq 'rating') {
-        $sortBy = 'threadRating';
-    } 
-    $sortBy = join('.', map { $self->session->db->dbh->quote_identifier($_) } split(/\./, $sortBy));
+    my $self    = shift;
+    my $session = $self->session;        
 
-	my $sql = "
-		select 
-			asset.assetId,
-			asset.className,
-			assetData.revisionDate as revisionDate 
-		from Thread 
-			left join asset on Thread.assetId=asset.assetId 
-			left join Post on Post.assetId=Thread.assetId and Thread.revisionDate = Post.revisionDate 
-			left join assetData on assetData.assetId=Thread.assetId and Thread.revisionDate = assetData.revisionDate 
-		where 
-			asset.parentId=".$self->session->db->quote($self->getId)." 
-			and asset.state='published' 
-			and asset.className='WebGUI::Asset::Post::Thread' 
-			and assetData.revisionDate=(
-				select
-					max(revisionDate) 
-				from 
-					assetData 
-				where 
-					assetData.assetId=asset.assetId 
-					and (status='approved' or status='archived')
-			) 
-			and status='approved'
-		group by 
-			assetData.assetId 
-		order by 
-			Thread.isSticky desc, 
-		".$sortBy." 
-			".$sortOrder;
-	my $p = WebGUI::Paginator->new($self->session,$self->getUrl,$self->get("threadsPerPage"));
-	$p->setDataByQuery($sql);
+    my $scratchSortBy    = $self->getId."_sortBy";
+    my $scratchSortOrder = $self->getId."_sortDir";
+    my $sortBy    = $self->session->form->process("sortBy")   
+                 || $self->session->scratch->get($scratchSortBy)
+                 || $self->get("sortBy");
+    $sortBy =~ s/^\w+\.//;
+    # Sort by the thread rating instead of the post rating.  other places don't care about threads.
+    $sortBy = $sortBy eq 'rating' ? 'threadRating' : $sortBy;
+    if (! WebGUI::Utility::isIn($sortBy, qw/userDefined1 userDefined2 userDefined3 userDefined4 userDefined5 title lineage revisionDate creationDate karmaRank threadRating views replies lastPostDate/)) {
+        $sortBy = 'revisionDate';
+    }
+    if ($sortBy eq 'assetId' || $sortBy eq 'revisionDate') {
+        $sortBy = 'assetData.' . $sortBy;
+    }
+    my $sortOrder = $self->session->form->process("sortOrder")
+                 || $self->session->scratch->get($scratchSortOrder)
+                 || $self->get("sortOrder");
+    #$sortOrder    = lc $sortOrder;
+    #$sortOrder    = 'desc' if ($sortOrder ne 'asc' && $sortOrder ne 'desc');
+    if ($sortBy ne $self->session->scratch->get($scratchSortBy) && $self->session->form->process("func") ne "editSave") {
+        $self->session->scratch->set($scratchSortBy,$self->session->form->process("sortBy"));
+        $self->session->scratch->set($scratchSortOrder, $sortOrder);
+    }
+    elsif ($self->session->form->process("sortBy") && $self->session->form->process("func") ne "editSave" && ! $self->session->form->process('sortOrder')) {
+        if ($sortOrder eq "asc") {
+            $sortOrder = "desc";
+        }
+        else {
+            $sortOrder = "asc";
+        }
+        $self->session->scratch->set($scratchSortOrder, $sortOrder);
+    }
+    $sortBy = join('.', map { $self->session->db->dbh->quote_identifier($_) } split(/\./, $sortBy));
+    $sortOrder ||= 'desc';
+
+    my $sql = "
+        select 
+            asset.assetId,
+            asset.className,
+            assetData.revisionDate as revisionDate 
+        from Thread 
+            left join asset on Thread.assetId=asset.assetId 
+            left join Post on Post.assetId=Thread.assetId and Thread.revisionDate = Post.revisionDate 
+            left join assetData on assetData.assetId=Thread.assetId and Thread.revisionDate = assetData.revisionDate 
+        where 
+            asset.parentId=".$self->session->db->quote($self->getId)." 
+            and asset.state='published' 
+            and asset.className='WebGUI::Asset::Post::Thread' 
+            and assetData.revisionDate=(
+                select
+                    max(revisionDate) 
+                from 
+                    assetData 
+                where 
+                    assetData.assetId=asset.assetId 
+                    and (status='approved' or status='archived')
+            ) 
+            and status='approved'
+        group by 
+            assetData.assetId 
+        order by 
+            Thread.isSticky desc, 
+        ".$sortBy."
+        ".$sortOrder;
+    my $p     = WebGUI::Paginator->new($self->session,$self->getUrl,$self->get("threadsPerPage"));
+    $p->setDataByQuery($sql);
 
     return $p;
 }
@@ -1576,6 +1586,23 @@ sub view {
 
 #-------------------------------------------------------------------
 
+=head2 www_edit 
+
+Override the master class to add an "Unarchive All" link.
+
+=cut
+
+sub www_edit {
+    my $self = shift;
+    return $self->session->privilege->insufficient() unless $self->canEdit;
+    return $self->session->privilege->locked() unless $self->canEditIfLocked;
+    my $i18n = WebGUI::International->new($self->session, 'Asset_Collaboration');
+    $self->getAdminConsole->addConfirmedSubmenuItem($self->getUrl('func=unarchiveAll'),$i18n->get("unarchive all"),$i18n->get("unarchive confirm"));
+    return $self->getAdminConsole->render($self->getEditForm->print,$i18n->get("assetName"));
+}
+
+#-------------------------------------------------------------------
+
 =head2 www_search ( )
 
 The web method to display and use the forum search interface.
@@ -1590,7 +1617,8 @@ sub www_search {
 	
     my $query   = $self->session->form->process("query","text");
     $var->{'form.header'} = WebGUI::Form::formHeader($self->session,{
-        action=>$self->getUrl("func=search;doit=1")
+        action=> $self->getUrl("func=search;doit=1"),
+        method=> 'GET',
     });
     $var->{'query.form'}  = WebGUI::Form::text($self->session,{
         name  => 'query',
@@ -1631,6 +1659,35 @@ sub www_subscribe {
         return $self->www_view;
 }
 
+#----------------------------------------------------------------------------
+
+=head2 www_unarchiveAll ( )
+
+Unarchive all the threads in this collaboration system
+
+=cut
+
+sub www_unarchiveAll {
+    my ( $self ) = @_;
+    my $session     = $self->session;
+    return $session->privilege->insufficient() unless $self->canEdit;
+    my $pb      = WebGUI::ProgressBar->new($session);
+    my $i18n     = WebGUI::International->new($session, 'Asset_Collaboration');
+    $pb->start($i18n->get('unarchive all'), $self->getUrl('func=edit'));
+    my $threadIds = $self->getLineage(['children'],{
+        includeOnlyClasses      => [ 'WebGUI::Asset::Post::Thread' ],
+        statusToInclude         => [ 'archived' ],
+    } );
+    ASSET: foreach my $threadId (@$threadIds) {
+        my $thread = WebGUI::Asset->newPending($session, $threadId);
+        if (!$thread || !$thread->canEdit) {
+            next ASSET;
+        }
+        $thread->unarchive;
+    }
+    return $pb->finish( $self->getUrl('func=edit') );
+}
+
 #-------------------------------------------------------------------
 
 =head2 www_unsubscribe (  )
