@@ -221,14 +221,13 @@ sub deleteTab {
 =head2 getContentLastModified 
 
 Extends the base method to modify caching.  If the currentView is in list mode, or
-an entry is being viewed, bypass caching altogether.
+an entry is being viewed, or the DataForm has a captcha, bypass caching altogether.
 
 =cut
 
 sub getContentLastModified {
     my $self = shift;
-    my $hasCaptcha = isIn('Captcha', map { $_->{type} } map { $self->getFieldConfig($_) } @{ $self->getFieldOrder });
-    if ($self->currentView eq 'list' || $self->session->form->process('entryId') || $hasCaptcha) {
+    if ($self->currentView eq 'list' || $self->session->form->process('entryId') || $self->hasCaptcha) {
         return time;
     }
     return $self->SUPER::getContentLastModified;
@@ -236,6 +235,19 @@ sub getContentLastModified {
 
 #-------------------------------------------------------------------
 
+=head2 hasCaptcha
+
+Returns true if the DataForm uses a captcha as one of the fields.
+
+=cut
+
+sub hasCaptcha {
+    my $self = shift;
+    return isIn('Captcha', map { $_->{type} } map { $self->getFieldConfig($_) } @{ $self->getFieldOrder });
+}
+
+#-------------------------------------------------------------------
+
 =head2 renameField ($oldName, $newName)
 
 Renames a field by name
@@ -721,9 +733,11 @@ sub getListTemplateVars {
     while ( my $entry = $entryIter->() ) {
         my $entryData = $entry->fields;
         my @dataLoop;
+        my %dataVars;
         for my $fieldName ( @{ $self->getFieldOrder } ) {
             my $field = $fieldConfig->{$fieldName};
             my $form = $self->_createForm($field, $entryData->{$fieldName});
+            $dataVars{ 'record.noloop.' . $fieldName } = $entryData->{$fieldName};
             push @dataLoop, {
                 "record.data.name"          => $field->{name},
                 "record.data.label"         => $field->{label},
@@ -733,6 +747,7 @@ sub getListTemplateVars {
             };
         }
         push @recordLoop, {
+            %dataVars,
             "record.ipAddress"              => $entry->ipAddress,
             "record.edit.url"               => $self->getFormUrl("func=view;entryId=".$entry->getId),
             "record.edit.icon"              => $session->icon->edit("func=view;entryId=".$entry->getId, $self->get('url')),
@@ -1264,6 +1279,9 @@ sub viewForm {
         $entry = $self->entryClass->new($self, ($entryId && $self->canEdit) ? $entryId : ());
     }
     $var = $passedVars || $self->getRecordTemplateVars($var, $entry);
+    if ($self->hasCaptcha) {
+        $self->session->http->setCacheControl('none');
+    }
     return $self->processTemplate($var, undef, $self->{_viewFormTemplate});
 }
 
