@@ -345,34 +345,6 @@ sub definition {
 
 #----------------------------------------------------------------------------
 
-=head2 addChild ( properties, [...] )
-
-Add a child to this asset. See C<WebGUI::AssetLineage> for more info.
-
-Overridden to ensure that only GalleryAlbums are added to Galleries.
-
-=cut
-
-sub addChild {
-    my $self        = shift;
-    my $properties  = shift;
-    my $albumClass  = "WebGUI::Asset::Wobject::GalleryAlbum";
-
-    # Load the class
-    WebGUI::Pluggable::load( $properties->{className} );
-
-    if ( !$properties->{className}->isa( $albumClass ) ) {
-        $self->session->errorHandler->security(
-            "add a ".$properties->{className}." to a ".$self->get("className")
-        );
-        return undef;
-    }
-
-    return $self->next::method( $properties, @_ );
-}
-
-#----------------------------------------------------------------------------
-
 =head2 appendTemplateVarsSearchForm ( var )
 
 Appends the template vars for the search form to the hash reference C<var>.
@@ -761,11 +733,12 @@ sub getRssFeedItems {
             perpage     => $self->get('itemsPerFeed'),
         } );
     
-    my $var = [];
+    my $var     = [];
+    my $siteUrl = $self->session->url->getSiteURL();
     for my $assetId ( @{ $p->getPageData } ) {
         my $asset       = WebGUI::Asset::Wobject::GalleryAlbum->newPending( $self->session, $assetId );
         push @{ $var }, {
-            'link'          => $asset->getUrl,
+            'link'          => $siteUrl . $asset->getUrl,
             'guid'          => $asset->{_properties}->{ 'assetId' },
             'title'         => $asset->getTitle,
             'description'   => $asset->{_properties}->{ 'description' },
