@@ -35,6 +35,8 @@ use Archive::Any;
 
 =head1 METHODS
 
+=cut
+
 #-------------------------------------------------------------------
 
 =head2 definition ( )
@@ -118,6 +120,7 @@ sub addArchive {
     my $properties  = shift;
     my $outputSub   = shift || sub {};
     my $gallery     = $self->getParent;
+    my $session     = $self->session;
     
     my $archive     = Archive::Any->new( $filename );
 
@@ -143,7 +146,7 @@ sub addArchive {
         my $class       = $gallery->getAssetClassForFile( $filePath );
         next unless $class; # class is undef for those files the Gallery can't handle
 
-        $self->session->errorHandler->info( "Adding $filename to album!" );
+        $session->errorHandler->info( "Adding $filename to album!" );
         $outputSub->('Adding %s to album', $filename);
         # Remove the file extension
         $filename   =~ s{\.[^.]+}{};
@@ -151,13 +154,14 @@ sub addArchive {
         $properties->{ className        } = $class;
         $properties->{ menuTitle        } = $filename;
         $properties->{ title            } = $filename;
-        $properties->{ url              } = $self->session->url->urlize( $self->getUrl . "/" . $filename );
+        $properties->{ ownerUserId      } = $session->user->userId;
+        $properties->{ url              } = $session->url->urlize( $self->getUrl . "/" . $filename );
 
         my $asset   = $self->addChild( $properties, undef, undef, { skipAutoCommitWorkflows => 1 } );
         $asset->setFile( $filePath );
     }
 
-    my $versionTag      = WebGUI::VersionTag->getWorking( $self->session );
+    my $versionTag      = WebGUI::VersionTag->getWorking( $session );
     $versionTag->set({ 
         "workflowId" => $self->getParent->get("workflowIdCommit"),
     });
@@ -169,37 +173,6 @@ sub addArchive {
 
 #----------------------------------------------------------------------------
 
-=head2 addChild ( properties [, ... ] )
-
-Add a child to this GalleryAlbum. See C<WebGUI::AssetLineage> for more info.
-
-Override to ensure only appropriate classes get added to GalleryAlbums.
-
-=cut
-
-sub addChild {
-    my $self        = shift;
-    my $properties  = shift;
-    my $fileClass   = 'WebGUI::Asset::File::GalleryFile';
-    
-    # Load the class
-    WebGUI::Pluggable::load( $properties->{className} );
-
-    # Make sure we only add appropriate child classes
-    if ( !$properties->{className}->isa( $fileClass ) 
-        && !$properties->{ className }->isa( "WebGUI::Asset::Shortcut" ) 
-        ) {
-        $self->session->errorHandler->security(
-            "add a ".$properties->{className}." to a ".$self->get("className")
-        );
-        return undef;
-    }
-
-    return $self->next::method( $properties, @_ );
-}
-
-#----------------------------------------------------------------------------
-
 =head2 appendTemplateVarsFileLoop ( vars, assetIds )
 
 Append template vars for a file loop for the specified assetIds. C<vars> is
