@@ -363,7 +363,7 @@ sub view {
     my $url = $self->session->url;
 	my $i18n = WebGUI::International->new($self->session, "Asset_UserList");
 	my (%var, @users, @profileField_loop, @profileFields);
-	my ($defaultPublicProfile, $defaultPublicEmail, $user, $sth, $sql, $profileField);
+	my ($user, $sth, $sql, $profileField);
 
     my $currentUrlWithoutSort = $self->getUrl();
     foreach ($form->param) {
@@ -506,17 +506,18 @@ sub view {
 	$sql .= " and ".$constraint if ($constraint);
 
 	my $sortBy = $form->process('sortBy') || $self->get('sortBy') || 'users.username';
-	my $sortOrder = $form->process('sortOrder') || $self->get('sortOrder') || 'asc';
+	my $sortOrder = $form->process('sortOrder') || $self->get('sortOrder');
+    if (lc $sortOrder ne 'desc') {
+        $sortOrder = 'asc';
+    }
 	
     my @sortByUserProperties = ('dateCreated', 'lastUpdated', 'karma', 'userId');
     if(isIn($sortBy,@sortByUserProperties)){
             $sortBy = 'users.'.$sortBy;
     }
+    $sortBy = join '.', map { $self->session->db->quoteIdentifier($_) } split /\./, $sortBy;
 	$sql .= " order by ".$sortBy." ".$sortOrder;
 
-	($defaultPublicProfile) = $self->session->db->quickArray("SELECT dataDefault FROM userProfileField WHERE fieldName='publicProfile'");
-	($defaultPublicEmail) = $self->session->db->quickArray("SELECT dataDefault FROM userProfileField WHERE fieldName='publicEmail'");
-
 	my $paginatePage = $form->param('pn') || 1;
 	my $currentUrl = $self->getUrl();
 	foreach ($form->param) {
@@ -602,7 +603,7 @@ sub view {
 	$var{user_loop}             = \@users;
     $var{alphabetSearch_loop}   = $self->getAlphabetSearchLoop($self->get("alphabetSearchField"),$self->get("alphabet"));
 
-	$var{searchFormHeader}      = WebGUI::Form::formHeader($self->session,{action => $self->getUrl});
+	$var{searchFormHeader}      = WebGUI::Form::formHeader($self->session,{action => $self->getUrl, method => 'GET', });
     $var{searchFormSubmit}      = WebGUI::Form::submit($self->session,{value => $i18n->get('submit search label')});
     $var{searchFormFooter}      = WebGUI::Form::formFooter($self->session);
 
