@@ -11,7 +11,11 @@ package WebGUI::Asset::Wobject::WikiMaster;
 #-------------------------------------------------------------------
 
 use Class::C3;
-use base qw(WebGUI::AssetAspect::RssFeed WebGUI::Asset::Wobject);
+use base qw(
+    WebGUI::AssetAspect::Subscribable 
+    WebGUI::AssetAspect::RssFeed 
+    WebGUI::Asset::Wobject
+);
 use strict;
 use Tie::IxHash;
 use WebGUI::International;
@@ -21,6 +25,24 @@ use URI::Escape;
 
 #-------------------------------------------------------------------
 
+=head2 appendFeaturedPageVars ( var, asset )
+
+Append the template variables to C<var> for the featured page C<asset>. Returns
+the C<var> for convenience.
+
+=cut
+
+sub appendFeaturedPageVars {
+    my ( $self, $var, $asset ) = @_;
+    my $assetVar = $asset->getTemplateVars;
+    for my $key ( keys %{$assetVar} ) {
+        $var->{ 'featured_' . $key } = $assetVar->{$key};
+    }
+    return $var;
+}
+
+#-------------------------------------------------------------------
+
 =head2 appendMostPopular ($var, [ $limit ])
 
 =head3 $var
@@ -35,10 +57,10 @@ If passed in, this will override the mostPopularCount set in the object.
 =cut
 
 sub appendMostPopular {
-	my $self = shift;
-	my $var = shift;
-	my $limit = shift || $self->get("mostPopularCount");
-	foreach my $asset (@{$self->getLineage(["children"],{returnObjects=>1, limit=>$limit, includeOnlyClasses=>["WebGUI::Asset::WikiPage"]})}) { 
+    my $self  = shift;
+    my $var   = shift;
+    my $limit = shift || $self->get("mostPopularCount");
+	foreach my $asset (@{$self->getLineage(["children"],{returnObjects=>1, limit=>$limit, includeOnlyClasses=>["WebGUI::Asset::WikiPage"], joinClass => 'WebGUI::Asset::WikiPage', orderByClause => 'WikiPage.views DESC'})}) { 
 		if (defined $asset) {
 			push(@{$var->{mostPopular}}, {
 				title=>$asset->getTitle,
@@ -126,7 +148,7 @@ sub appendSearchBoxVars {
 	my $queryText = shift;
 	my $submitText = WebGUI::International->new($self->session, 'Asset_WikiMaster')->get('searchLabel');
 	$var->{'searchFormHeader'} = join '',
-	    (WebGUI::Form::formHeader($self->session, { action => $self->getUrl}),
+	    (WebGUI::Form::formHeader($self->session, { action => $self->getUrl, method => 'GET', }),
 	     WebGUI::Form::hidden($self->session, { name => 'func', value => 'search' }));
 	$var->{'searchQuery'} = WebGUI::Form::text($self->session, { name => 'query', value => $queryText });
 	$var->{'searchSubmit'} = WebGUI::Form::submit($self->session, { value => $submitText });
@@ -209,7 +231,7 @@ sub autolinkHtml {
 =head2 canAdminister 
 
 Returns true if the current user is in the groupToAdminister group, or the user can edit
-this WikiMaster.
+this WikiMaster due to groupIdEdit or ownerUserId.
 
 =cut
 
@@ -222,33 +244,27 @@ sub canAdminister {
 
 =head2 canEdit ( )
 
-Overriding canEdit method to check permissions correctly when someone is adding a wikipage
+Overriding canEdit method to check permissions correctly when someone is adding a wikipage.
 
 =cut
 
 sub canEdit {
-        my $self = shift;
-        return (
-                (
-                        (
-                                $self->session->form->process("func") eq "add" ||
-                                (
-                                        $self->session->form->process("assetId") eq "new" &&
-                                        $self->session->form->process("func") eq "editSave" &&
-                                        $self->session->form->process("class") eq "WebGUI::Asset::WikiPage"
-                                )
-                        ) &&
-                        $self->canEditPages
-                ) || # account for new posts
-                $self->next::method()
-        );
+    my $self = shift;
+    my $form      = $self->session->form;
+    my $addNew    = $form->process("func"              ) eq "add";
+    my $editSave  = $form->process("assetId"           ) eq "new"
+                 && $form->process("func"              ) eq "editSave"
+                 && $form->process("class","className" ) eq "WebGUI::Asset::WikiPage";
+    my $canEdit = ( ($addNew || $editSave) && $self->canEditPages )
+               || $self->next::method();
+    return $canEdit;
 }
 
 #-------------------------------------------------------------------
 
 =head2 canEditPages 
 
-Returns true is the current user is in the group that can edit page, or if
+Returns true is the current user is in the group that can edit pages, or if
 they can administer the wiki (canAdminister).
 
 =cut
@@ -426,6 +442,25 @@ sub definition {
 
 #-------------------------------------------------------------------
 
+=head2 getFeaturedPageIds ( )
+
+Get the asset IDs of the pages that are marked as Featured.
+
+=cut
+
+sub getFeaturedPageIds {
+    my ( $self ) = @_;
+
+    my $assetIds    = $self->getLineage( ['children'], {
+        joinClass       => 'WebGUI::Asset::WikiPage',
+        whereClause     => 'isFeatured = 1',
+    } );
+    
+    return $assetIds;
+}
+
+#-------------------------------------------------------------------
+
 =head2 getRssFeedItems ()
 
 Returns an array reference of hash references. Each hash reference has a title,
@@ -455,6 +490,36 @@ sub getRssFeedItems {
     return $var;
 }
 
+#----------------------------------------------------------------------------
+
+=head2 getTemplateVars ( )
+
+Get the common template variables for all views of the wiki.
+
+=cut
+
+sub getTemplateVars {
+    my ( $self ) = @_;
+    my $i18n    = WebGUI::International->new($self->session, "Asset_WikiMaster");
+    my $var     = { %{$self->get},
+        url                 => $self->getUrl,
+        searchLabel         => $i18n->get("searchLabel"),	
+        mostPopularUrl      => $self->getUrl("func=mostPopular"),
+        mostPopularLabel    => $i18n->get("mostPopularLabel"),
+        addPageLabel        => $i18n->get("addPageLabel"),
+        addPageUrl          => $self->getUrl("func=add;class=WebGUI::Asset::WikiPage"),
+        recentChangesUrl    => $self->getUrl("func=recentChanges"),
+        recentChangesLabel  => $i18n->get("recentChangesLabel"),
+        restoreLabel        => $i18n->get("restoreLabel"),
+        canAdminister       => $self->canAdminister,
+        isSubscribed        => $self->isSubscribed,
+        subscribeUrl        => $self->getSubscribeUrl,
+        unsubscribeUrl      => $self->getUnsubscribeUrl,
+    };
+    
+    return $var;
+}
+
 #-------------------------------------------------------------------
 
 =head2 prepareView 
@@ -503,6 +568,19 @@ sub processPropertiesFromFormPost {
 
 #-------------------------------------------------------------------
 
+=head2 shouldSkipNotification ( )
+
+WikiMasters do not send notification
+
+=cut
+
+sub shouldSkipNotification {
+    my ( $self ) = @_;
+    return 1;
+}
+
+#-------------------------------------------------------------------
+
 =head2 view 
 
 Render the front page of the wiki.
@@ -511,24 +589,24 @@ Render the front page of the wiki.
 
 sub view {
 	my $self = shift;
-	my $i18n = WebGUI::International->new($self->session, "Asset_WikiMaster");
-	my $var = {
-		description => $self->autolinkHtml($self->get('description')),
-		searchLabel=>$i18n->get("searchLabel"),	
-		mostPopularUrl=>$self->getUrl("func=mostPopular"),
-		mostPopularLabel=>$i18n->get("mostPopularLabel"),
-		addPageLabel=>$i18n->get("addPageLabel"),
-		addPageUrl=>$self->getUrl("func=add;class=WebGUI::Asset::WikiPage"),
-		recentChangesUrl=>$self->getUrl("func=recentChanges"),
-		recentChangesLabel=>$i18n->get("recentChangesLabel"),
-		restoreLabel => $i18n->get("restoreLabel"),
-		canAdminister => $self->canAdminister,
-        keywordCloud => WebGUI::Keyword->new($self->session)->generateCloud({
-            startAsset=>$self,
-            displayFunc=>"byKeyword",
-            }),
-		};
+    my $session = $self->session;
+        my $var = $self->getTemplateVars;
+        $var->{ description     } = $self->autolinkHtml( $var->{ description } );
+        $var->{ keywordCloud } 
+            = WebGUI::Keyword->new($self->session)->generateCloud({
+                startAsset=>$self,
+                displayFunc=>"byKeyword",
+            });
 	my $template = $self->{_frontPageTemplate};
+
+    # Get a random featured page
+    my $featuredIds = $self->getFeaturedPageIds;
+    my $featuredId  = $featuredIds->[ int( rand @$featuredIds ) - 1 ]; 
+    my $featured    = WebGUI::Asset->newByDynamicClass( $session, $featuredId );
+    if ( $featured ) {
+        $self->appendFeaturedPageVars( $var, $featured );
+    }
+
 	$self->appendSearchBoxVars($var);
 	$self->appendRecentChanges($var, $self->get('recentChangesCountFront'));
 	$self->appendMostPopular($var, $self->get('mostPopularCountFront'));
@@ -648,19 +726,13 @@ sub www_search {
 		wikiHomeUrl=>$self->getUrl,
 		addPageUrl=>$self->getUrl("func=add;class=WebGUI::Asset::WikiPage;title=".$queryString),
 		};
-    if (defined $queryString) {
-        $self->session->scratch->set('wikiSearchQueryString', $queryString);
-    }
-    else {
-        $queryString = $self->session->scratch->get('wikiSearchQueryString');
-    }
 	$self->appendSearchBoxVars($var, $queryString);
 	if (length $queryString) {
 		my $search = WebGUI::Search->new($self->session);
 		$search->search({ keywords => $queryString,
 				  lineage => [$self->get('lineage')],
 				  classes => ['WebGUI::Asset::WikiPage'] });
-		my $rs = $search->getPaginatorResultSet($self->getUrl("func=search"));
+		my $rs = $search->getPaginatorResultSet($self->getUrl("func=search;query=".$queryString));
 		$rs->appendTemplateVars($var);
 		my @results = ();
 		foreach my $row (@{$rs->getPageData}) {
