@@ -66,7 +66,7 @@ sub addChild {
 	my $self        = shift;
 	my $properties  = shift;
 	my $id          = shift || $self->session->id->generate();
-	my $now         = shift || $self->session->datetime->time();
+	my $now         = shift || time();
 	my $options     = shift;
 
 	# Check if it is possible to add a child to this asset. If not add it as a sibling of this asset.
@@ -391,10 +391,6 @@ sub getLineage {
 	
     my $sql = $self->getLineageSql($relatives,$rules);
 
-    unless ($sql) {
-        return [];
-    }
-
 	my @lineage;
 	my %relativeCache;
 	my $sth = $self->session->db->read($sql);
@@ -662,7 +658,8 @@ sub getLineageSql {
 	}
 	## finish up our where clause
 	if (!scalar(@whereModifiers)) {
-        return "";
+        #Return valid SQL that will never select an asset.
+        return q|select * from asset where assetId="###---###"|;
     }
 	$where .= ' and ('.join(" or ",@whereModifiers).')';
 	if (exists $rules->{whereClause} && $rules->{whereClause}) {
