@@ -128,6 +128,14 @@ from the asset where it is deployed.
 Forces the package to ignore the revisionDate inside it.  This makes the imported package the
 latest revision of an asset.
 
+=head4 clearPackageFlag
+
+Clears the isPackage flag on the incoming asset.
+
+=head4 setDefaultTemplate
+
+Set the isDefault flag on the incoming asset.  Really only works on templates.
+
 =cut
 
 sub importAssetData {
@@ -150,6 +158,12 @@ sub importAssetData {
         delete $properties{groupIdView};
         delete $properties{groupIdEdit};
     }
+    if ($options->{clearPackageFlag}) {
+        $properties{isPackage} = 0;
+    }
+    if ($options->{setDefaultTemplate}) {
+        $properties{isDefault} = 1;
+    }
     if ($revisionExists) { # update an existing revision
         $asset = WebGUI::Asset->new($self->session, $id, $class, $version);
 
@@ -175,16 +189,10 @@ sub importAssetData {
         };
         if (defined $asset) {   # create a new revision of an existing asset
             $error->info("Creating a new revision of asset $id");
-            $asset = $asset->addRevision($data->{properties}, $version, {skipAutoCommitWorkflows => 1});
+            $asset = $asset->addRevision(\%properties, $version, {skipAutoCommitWorkflows => 1});
         }
         else {  # add an entirely new asset
             $error->info("Adding $id that didn't previously exist.");
-            my %properties = %{ $data->{properties} };
-            if ($options->{inheritPermissions}) {
-                $properties{ownerUserId} = $self->get('ownerUserId');
-                $properties{groupIdView} = $self->get('groupIdView');
-                $properties{groupIdEdit} = $self->get('groupIdEdit');
-            }
             $asset = $self->addChild(\%properties, $id, $version, {skipAutoCommitWorkflows => 1});
         }
     }
