@@ -16,6 +16,7 @@ package WebGUI::Asset;
 
 use strict;
 use WebGUI::Asset::Shortcut;
+use JSON;
 
 =head1 NAME
 
@@ -289,7 +290,7 @@ sub trash {
     $db->beginTransaction;
     $outputSub->($i18n->get('Clearing asset tables'));
     $db->write("update asset set state='trash-limbo' where lineage like ?",[$self->get("lineage").'%']);
-    $db->write("update asset set state='trash', stateChangedBy=?, stateChanged=? where assetId=?",[$session->user->userId, $session->datetime->time(), $self->getId]);
+    $db->write("update asset set state='trash', stateChangedBy=?, stateChanged=? where assetId=?",[$session->user->userId, time(), $self->getId]);
     $db->commit;
 
     # Update ourselves since we didn't use update()
@@ -392,15 +393,19 @@ sub www_manageTrash {
 	my $ac = WebGUI::AdminConsole->new($self->session,"trash");
 	my $i18n = WebGUI::International->new($self->session,"Asset");
 	return $self->session->privilege->insufficient() unless ($self->session->user->isInGroup(12));
-	my ($header, $limit);
-        $ac->setHelp("trash manage");
-	if ($self->session->form->process("systemTrash") && $self->session->user->isAdmin) {
+    $ac->setHelp("trash manage");
+    my $header;
+    my $limit = 1;
+    my $canAdmin = $self->session->user->isInGroup($self->session->setting->get('groupIdAdminTrash'));
+    my $systemTrash = $self->session->form->process("systemTrash");
+    if ($systemTrash && $canAdmin) {
 		$header = $i18n->get(965);
 		$ac->addSubmenuItem($self->getUrl('func=manageTrash'), $i18n->get(10,"WebGUI"));
-	} else {
-		$ac->addSubmenuItem($self->getUrl('func=manageTrash;systemTrash=1'), $i18n->get(964));
-		$limit = 1;
+        $limit = undef;
 	}
+    elsif ( $canAdmin ) {
+        $ac->addSubmenuItem($self->getUrl('func=manageTrash;systemTrash=1'), $i18n->get(964));
+    }
   	$self->session->style->setLink($self->session->url->extras('assetManager/assetManager.css'), {rel=>"stylesheet",type=>"text/css"});
         $self->session->style->setScript($self->session->url->extras('assetManager/assetManager.js'), {type=>"text/javascript"});
 	my $output = "
@@ -413,26 +418,43 @@ sub www_manageTrash {
          assetManager.AddColumn('".$i18n->get("last updated")."','','center','');
          assetManager.AddColumn('".$i18n->get("size")."','','right','');
          \n";
+
+    # To avoid string escaping issues
+    my $json = JSON->new;
+    my $amethod = sub {
+        my ($method, @args) = @_;
+        my $array = $json->encode(\@args);
+        $array =~ s/^\[//;
+        $array =~ s/\]$//;
+        $output .= "assetManager.$method($array);\n";
+    };
 	foreach my $child (@{$self->getAssetsInTrash($limit)}) {
-		my $title = $child->getTitle;
-                $title =~ s/\'/\\\'/g;
+    		my $title = $child->getTitle;
     		my $plus =$child->getChildCount({includeTrash => 1}) ? "+ " : "&nbsp;&nbsp;&nbsp;&nbsp;";
-         	$output .= "assetManager.AddLine('"
-			.WebGUI::Form::checkbox($self->session, {
-				name=>'assetId',
-				value=>$child->getId
-				})
-			."','" . $plus . "<a href=\"".$child->getUrl("op=assetManager")."\">" . $title
-			."</a>','<p style=\"display:inline;vertical-align:middle;\"><img src=\"".$child->getIcon(1)."\" style=\"vertical-align:middle;border-style:none;\" alt=\"".$child->getName."\" /></p> ".$child->getName
-			."','".$self->session->datetime->epochToHuman($child->get("revisionDate"))
-			."','".formatBytes($child->get("assetSize"))."');\n";
-         	$output .= "assetManager.AddLineSortData('','".$title."','".$child->getName
-			."','".$child->get("revisionDate")."','".$child->get("assetSize")."');\n";
+            $amethod->('AddLine',
+                WebGUI::Form::checkbox($self->session, {
+                    name=>'assetId',
+                    value=>$child->getId
+                }),
+                qq($plus<a href=").$child->getUrl("op=assetManager")
+                .qq(">$title</a>),
+			    '<p style="display:inline;vertical-align:middle;"><img src="'
+                .$child->getIcon(1)
+                .'" style="vertical-align:middle;border-style:none;" alt='
+                .$child->getName .'" /></p> ' . $child->getName,
+                $self->session->datetime->epochToHuman($child->get("revisionDate")),
+                formatBytes($child->get("assetSize"))
+            );
+            $amethod->('AddLineSortData',
+                '', $title, $child->getName,
+                $child->get('revisionDate'), $child->get('assetSize')
+            );
 	}
 	$output .= '
             assetManager.AddButton("'.$i18n->get("restore").'","restoreList","manageTrash");
             assetManager.AddButton("'.$i18n->get("purge").'","purgeList","manageTrash");
             assetManager.AddFormHidden({ name:"webguiCsrfToken", value:"'.$self->session->scratch->get('webguiCsrfToken').'"});
+            assetManager.AddFormHidden({ name:"systemTrash", value:"'.$systemTrash.'"});
             assetManager.Write();        
             var assetListSelectAllToggle = false;
             function toggleAssetListSelectAll(form) {
@@ -482,6 +504,9 @@ sub www_purgeList {
         }
     }
     my $method = ($session->form->process("proceed")) ? $session->form->process('proceed') : 'manageTrash';
+    if ($session->form->process('systemTrash') ) {
+        $method .= ';systemTrash=1';
+    }
     $pb->finish($self->getUrl('func='.$method));
 }
 
