@@ -266,7 +266,7 @@ sub createAccountSave {
     $properties->{ changeUsername       } = $setting->get("webguiChangeUsername");
     $properties->{ changePassword       } = $setting->get("webguiChangePassword");   
     $properties->{ identifier           } = $self->hashPassword($password);
-    $properties->{ passwordLastUpdated  } = $session->datetime->time();
+    $properties->{ passwordLastUpdated  } = time();
     $properties->{ passwordTimeout      } = $setting->get("webguiPasswordTimeout");
     $properties->{ status } = 'Deactivated' if ($setting->get("webguiValidateEmail"));
 
@@ -288,7 +288,7 @@ WebGUI::Asset::Template->new($self->session,$self->getSetting('accountActivation
         WebGUI::Macro::process($self->session,\$text);
         $mail->addText($text);
         $mail->addFooter;
-        $mail->send;
+        $mail->queue;
         $self->user->status("Deactivated");
         $session->var->end($session->var->get("sessionId"));
         $session->var->start(1,$session->getId);
@@ -433,16 +433,16 @@ sub editUserFormSave {
    unless (!$identifier || $identifier eq "password") {
       $properties->{identifier} = $self->hashPassword($self->session->form->process('authWebGUI.identifier'));
 	   if($userData->{identifier} ne $properties->{identifier}){
-	     $properties->{passwordLastUpdated} =$self->session->datetime->time();
+	     $properties->{passwordLastUpdated} =time();
       }
    }
    $properties->{passwordTimeout} = $self->session->form->interval('authWebGUI.passwordTimeout');
    $properties->{changeUsername} = $self->session->form->process('authWebGUI.changeUsername');
    $properties->{changePassword} = $self->session->form->process('authWebGUI.changePassword');
    	if($userId eq "new") {
-   		$properties->{passwordLastUpdated} =$self->session->datetime->time();
+   		$properties->{passwordLastUpdated} =time();
 		if ($self->session->setting->get("webguiExpirePasswordOnCreation")){
-      			$properties->{passwordLastUpdated} =$self->session->datetime->time() - $properties->{passwordTimeout};   
+      			$properties->{passwordLastUpdated} =time() - $properties->{passwordTimeout};   
 		}
    	}
    
@@ -568,6 +568,13 @@ sub editUserSettingsForm {
 		-namespace => "Auth/WebGUI/Create",
 		-label     => $i18n->get("create account template"),
 		-hoverHelp => $i18n->get("create account template help"),
+    );
+    $f->template(
+        -name      => "webguiDeactivateAccountTemplate",
+        -value     => $self->session->setting->get("webguiDeactivateAccountTemplate"),
+        -namespace => "Auth/WebGUI/Deactivate",
+        -label     => $i18n->get("deactivate account template"),
+        -hoverHelp => $i18n->get("deactivate account template help"),
     );
 	$f->template(
 		-name      => "webguiExpiredPasswordTemplate",
@@ -649,15 +656,16 @@ sub editUserSettingsFormSave {
     }
 
 	$s->set("webguiPasswordRecoveryRequireUsername", $f->process("webguiPasswordRecoveryRequireUsername","yesNo"));
-	$s->set("webguiValidateEmail", $f->process("webguiValidateEmail","yesNo"));
-	$s->set("webguiUseCaptcha", $f->process("webguiUseCaptcha","yesNo"));
-	$s->set("webguiAccountTemplate", $f->process("webguiAccountTemplate","template"));
-	$s->set("webguiCreateAccountTemplate", $f->process("webguiCreateAccountTemplate","template"));
-	$s->set("webguiExpiredPasswordTemplate", $f->process("webguiExpiredPasswordTemplate","template"));
-	$s->set("webguiLoginTemplate", $f->process("webguiLoginTemplate","template"));
-	$s->set("webguiPasswordRecoveryTemplate", $f->process("webguiPasswordRecoveryTemplate","template"));
-    $s->set("webguiWelcomeMessageTemplate", $f->process("webguiWelcomeMessageTemplate","template"));
-    $s->set("webguiAccountActivationTemplate", $f->process("webguiAccountActivationTemplate","template")); 
+	$s->set("webguiValidateEmail",                   $f->process("webguiValidateEmail","yesNo"));
+	$s->set("webguiUseCaptcha",                      $f->process("webguiUseCaptcha","yesNo"));
+	$s->set("webguiAccountTemplate",                 $f->process("webguiAccountTemplate","template"));
+	$s->set("webguiCreateAccountTemplate",           $f->process("webguiCreateAccountTemplate","template"));
+	$s->set("webguiDeactivateAccountTemplate",       $f->process("webguiDeactivateAccountTemplate","template"));
+	$s->set("webguiExpiredPasswordTemplate",         $f->process("webguiExpiredPasswordTemplate","template"));
+	$s->set("webguiLoginTemplate",                   $f->process("webguiLoginTemplate","template"));
+	$s->set("webguiPasswordRecoveryTemplate",        $f->process("webguiPasswordRecoveryTemplate","template"));
+    $s->set("webguiWelcomeMessageTemplate",          $f->process("webguiWelcomeMessageTemplate","template"));
+    $s->set("webguiAccountActivationTemplate",       $f->process("webguiAccountActivationTemplate","template")); 
 
     if (@errors) {
         return \@errors;
@@ -679,6 +687,17 @@ sub getCreateAccountTemplateId {
 	return $self->session->setting->get("webguiCreateAccountTemplate") || "PBtmpl0000000000000011";
 }
 
+#-------------------------------------------------------------------
+sub getDeactivateAccountTemplateId {
+	my $self = shift;
+	return $self->session->setting->get("webguiDeactivateAccountTemplate") || $self->SUPER::getDeactivateAccountTemplateId;
+}
+
+#-------------------------------------------------------------------
+sub getDefaultLoginTemplateId {
+	return "PBtmpl0000000000000013";
+}
+
 #-------------------------------------------------------------------
 sub getExpiredPasswordTemplateId {
 	my $self = shift;
@@ -688,7 +707,7 @@ sub getExpiredPasswordTemplateId {
 #-------------------------------------------------------------------
 sub getLoginTemplateId {
 	my $self = shift;
-	return $self->session->setting->get("webguiLoginTemplate") || "PBtmpl0000000000000013";
+	return $self->session->setting->get("webguiLoginTemplate") || $self->getDefaultLoginTemplateId;
 }
 
 #-------------------------------------------------------------------
@@ -753,7 +772,7 @@ sub login {
    my $userData = $self->getParams;
    if($self->getSetting("passwordTimeout") && $userData->{passwordTimeout}){
       my $expireTime = $userData->{passwordLastUpdated} + $userData->{passwordTimeout};
-      if ($self->session->datetime->time() >= $expireTime){
+      if (time() >= $expireTime){
 		my $userId = $self->userId;
 		 $self->logout;
    	     return $self->resetExpiredPassword($userId);
@@ -1031,7 +1050,7 @@ sub profileRecoverPasswordFinish {
 		$self->user( $user );
 		$self->saveParams($userId, $self->authMethod,
 				  { identifier => $self->hashPassword($password),
-				    passwordLastUpdated => $self->session->datetime->time });
+				    passwordLastUpdated => time });
 		$self->_logSecurityMessage;
 		return $self->SUPER::login;
 	} else {
@@ -1086,7 +1105,7 @@ sub emailRecoverPasswordFinish {
 
     my $mail = WebGUI::Mail::Send->create($session, { to=>$email, subject=>$i18n->get('WebGUI password recovery')});
     $mail->addText($i18n->get('recover password email text1', 'AuthWebGUI') . $url. ". \n\n".$i18n->get('recover password email text2', 'AuthWebGUI')." \n\n ".$url."?op=auth;method=emailResetPassword;token=$recoveryGuid"."\n\n ". $i18n->get('recover password email text3', 'AuthWebGUI'));
-    $mail->send;
+    $mail->queue;
     return "<h1>". $i18n->get('recover password banner', 'AuthWebGUI')." </h1> <br> <br> <h3>". $i18n->get('email recover password finish message', 'AuthWebGUI') . "</h3>";
 }
 
@@ -1182,7 +1201,7 @@ sub emailResetPasswordFinish {
                $self->user(WebGUI::User->new($self->session, $userId));
                $self->saveParams($userId, $self->authMethod,
                                  { identifier => $self->hashPassword($password),
-                                   passwordLastUpdated => $self->session->datetime->time });
+                                   passwordLastUpdated => time });
                $self->_logSecurityMessage;
 
 #              delete the emailRecoverPasswordVerificationNumber
@@ -1236,7 +1255,7 @@ sub resetExpiredPasswordSave {
    return $self->resetExpiredPassword($u->userId, "<h1>".$i18n->get(70)."</h1><ul>".$error.'</ul>') if ($error);
    
    $properties->{identifier} = $self->hashPassword($self->session->form->process("identifier"));
-   $properties->{passwordLastUpdated} =$self->session->datetime->time();
+   $properties->{passwordLastUpdated} =time();
    
    $self->saveParams($u->userId,$self->authMethod,$properties);
    $self->_logSecurityMessage();
@@ -1299,7 +1318,7 @@ sub updateAccount {
    }
    
    if($error){
-      $display = $error;
+      $display = '<ul>'.$error.'</ul>';
    }
    
    my $properties;
@@ -1314,7 +1333,7 @@ sub updateAccount {
             $properties->{identifier} = $self->hashPassword($password);
 			$self->_logSecurityMessage();
 	        if($userData->{identifier} ne $properties->{identifier}){
-	           $properties->{passwordLastUpdated} =$self->session->datetime->time();
+	           $properties->{passwordLastUpdated} =time();
             }
          }
       }
