@@ -27,7 +27,7 @@ sub getClassSelectBox {
     );
     delete $classes{"WebGUI::Asset"}; # don't want to search for the root asset
 
-    my $className = $session->scratch->get('assetManagerSearchClassName') || $session->form->process("class","className");
+    my $className = $session->form->process("class","className") || $session->scratch->get('assetManagerSearchClassName');
     $session->scratch->set('assetManagerSearchClassName', $className);
     return WebGUI::Form::selectBox( $session, {
         name            => "class",
@@ -174,56 +174,56 @@ sub getMoreMenu {
     # These links are shown based on UI level
     if ( $userUiLevel >= $toolbarUiLevel->{ "changeUrl" } ) {
         push @more_fields, {
-            url     => '<url>?func=changeUrl;proceed=manageAssets', 
+            url     => 'func=changeUrl;proceed=manageAssets', 
             label   => $i18n->get( 'change url' ),
         };
     }
 
     if ( $userUiLevel >= $toolbarUiLevel->{ "editBranch" } ) {
         push @more_fields, {
-            url     => '<url>?func=editBranch', 
+            url     => 'func=editBranch', 
             label   => $i18n->get( 'edit branch' ),
         };
     }
 
     if ( $userUiLevel >= $toolbarUiLevel->{ "shortcut" } ) {
         push @more_fields, {
-            url     => '<url>?func=createShortcut;proceed=manageAssets', 
+            url     => 'func=createShortcut;proceed=manageAssets', 
             label   => $i18n->get( 'create shortcut' ),
         };
     }
 
     if ( $userUiLevel >= $toolbarUiLevel->{ "revisions" } ) {
         push @more_fields, {
-            url     => '<url>?func=manageRevisions',
+            url     => 'func=manageRevisions',
             label   => $i18n->get( 'revisions' ),
         };
     }
 
     if ( $userUiLevel >= $toolbarUiLevel->{ "view" } ) {
         push @more_fields, {
-            url     => '<url>',
+            url     => '',
             label   => $i18n->get( 'view' ),
         };
     }
 
     if ( $userUiLevel >= $toolbarUiLevel->{ "edit" } ) {
         push @more_fields, {
-            url     => '<url>?func=edit;proceed=manageAssets',
+            url     => 'func=edit;proceed=manageAssets',
             label   => $i18n->get( 'edit' ),
         };
     }
 
     if ( $userUiLevel >= $toolbarUiLevel->{ "lock" } ) {
         push @more_fields, {
-            url     => '<url>?func=lock;proceed=manageAssets',
+            url     => 'func=lock;proceed=manageAssets',
             label   => $i18n->get( 'lock' ),
         };
     }
 
     if ( $session->config->get("exportPath") && $userUiLevel >= $toolbarUiLevel->{"export"} ) {
         push @more_fields, {
-            url     => '<url>?func=export',
+            url     => 'func=export',
             label   => $i18n->get( 'Export Page' ),
         };
     }
@@ -411,11 +411,11 @@ ENDHTML
 <div id="dataTableContainer">
 </div>
 <p class="actions"> %s 
-<input type="submit" name="action_update" value="%s" onclick="this.form.func.value='setRanks'; this.form.submit();" />
-<input type="submit" name="action_delete" value="%s" onclick="if( confirm('%s')){ this.form.func.value='deleteList'; this.form.submit(); }{ return false; }" />
-<input type="submit" name="action_cut" value="%s" onclick="this.form.func.value='cutList'; this.form.submit();"/>
-<input type="submit" name="action_copy" value="%s"  onclick="this.form.func.value='copyList'; this.form.submit();"/>
-<input type="submit" name="action_duplicate" value="%s"  onclick="this.form.func.value='duplicateList'; this.form.submit();"/>
+<input type="submit" name="action_update" value="%s" onclick="this.form.func.value='setRanks'; this.form.submit(); return false;" />
+<input type="submit" name="action_delete" value="%s" onclick="if( confirm('%s')){ this.form.func.value='deleteList'; this.form.submit(); return false;}{ return false; }" />
+<input type="submit" name="action_cut" value="%s" onclick="this.form.func.value='cutList'; this.form.submit(); return false;"/>
+<input type="submit" name="action_copy" value="%s"  onclick="this.form.func.value='copyList'; this.form.submit(); return false;"/>
+<input type="submit" name="action_duplicate" value="%s"  onclick="this.form.func.value='duplicateList'; this.form.submit(); return false;"/>
 </p>
 </form>
 <div id="pagination">
