@@ -59,6 +59,7 @@ our $HELP = {
             {   name        => 'canEdit',
                 description => 'canEdit variable',
             },
+            {   name        => 'canAdminister', },
             {   name        => 'isProtected', },
             {   name        => 'historyLabel',
                 description => 'historyLabel variable',
@@ -77,6 +78,32 @@ our $HELP = {
             },
             { 'name' => 'editContent', },
             { 'name' => 'content', },
+            { 'name' => 'keywordsLoop',
+              'variables' => [
+                { 'name' => 'keyword',
+                  'description' => 'keyword title',
+                },
+                { 'name' => 'url',
+                  'description' => 'keyword url',
+                },
+              ],
+            },
+            {
+                name        => 'isSubscribed',
+                description => 'help isSubscribed',
+            },
+            {
+                name        => 'subscribeUrl',
+                description => 'help subscribeUrl',
+            },
+            {
+                name        => 'unsubscribeUrl',
+                description => 'help unsubscribeUrl',
+            },
+            {
+                name        => 'owner',
+                description => 'help owner',
+            },
         ],
         related => [],
     },
@@ -111,6 +138,17 @@ our $HELP = {
         related => [],
     },
 
+
+    'subscription template' => {
+        title       => 'help subscription title',
+        body        => 'help subscription body',
+        isa         => [
+            {
+                tag       => 'view template',
+                namespace => 'Asset_WikiPage',
+            },
+        ],
+    },
 };
 
 1;
