@@ -253,8 +253,7 @@ sub delete {
     );
     #Delete the message from the database if everyone who was sent the message has deleted it
     unless ($isActive) {
-        $db->write("delete from inbox where messageId=?",[$messageId]);
-        $db->write("delete from inbox_messageState where messageId=?",[$messageId]);
+        $self->purge;
     }
 }
 
@@ -437,6 +436,22 @@ sub new {
 
 #-------------------------------------------------------------------
 
+=head2 purge
+
+Completely deletes a message from the inbox.
+
+=cut
+
+sub purge {
+	my $self = shift;
+    my $db   = $self->session->db;
+    my $messageId = $self->getId;
+    $db->write("delete from inbox where messageId=?",[$messageId]);
+    $db->write("delete from inbox_messageState where messageId=?",[$messageId]);
+}
+
+#-------------------------------------------------------------------
+
 =head2 session
 
 Returns a reference to the current session.
