@@ -277,7 +277,7 @@ sub getUserSearchForm {
 	$session->scratch->set("userSearchModifier",$session->form->process("modifier")) if defined($session->form->process("modifier"));
 	my $i18n = WebGUI::International->new($session);
 	my $output = '<div align="center">'
-		.WebGUI::Form::formHeader($session,)
+		.WebGUI::Form::formHeader($session,{ method => 'GET'}, )
 		.WebGUI::Form::hidden($session,
 			name => "op",
 			value => $op
@@ -720,9 +720,9 @@ sub www_editUser {
 	my @include; 
 	foreach my $group (@exclude) {
 		unless (
-			$group eq "1" || $group eq "2" || $group eq "7" # can't remove user from magic groups 
-			|| ($session->user->userId eq $u->userId  && $group eq 3) # cannot remove self from admin
-			|| ($u->isAdmin && $group eq "3") # admin user cannot be remove from admin
+			$group eq "1" || $group eq "2" || $group eq "7"     # can't remove user from magic groups 
+			|| ($session->user->userId eq $uid  && $group eq 3) # cannot remove self from admin
+			|| ($uid eq '3' && $group eq "3")                   # user Admin cannot be removed from admin group
 			) {
 			push(@include,$group);
 		}
@@ -841,7 +841,7 @@ sub www_editUserSave {
         }
 	# Display an error telling them the username they are trying to use is not available and suggest alternatives	
 	} else {
-       		$error = '<ul>' . sprintf($i18n->get(77), $postedUsername, $postedUsername, $postedUsername, $session->datetime->epochToHuman($session->datetime->time(),"%y")).'</ul>';
+       		$error = '<ul>' . sprintf($i18n->get(77), $postedUsername, $postedUsername, $postedUsername, $session->datetime->epochToHuman(time(),"%y")).'</ul>';
 	}
 	if ($isSecondary) {
 		return _submenu($session,{workarea => $i18n->get(978)});
