@@ -203,15 +203,24 @@ sub buildHashRef {
     unless ($options->{noOrder}) {
         tie %hash, "Tie::IxHash";
     }
-    my $sth = $self->prepare($sql);
-    $sth->execute($params);
-    while (my @data = $sth->array) {
-        my $value = pop @data;
-        my $key = join(":", @data); # if more than two columns is selected, join them together with :
-        $key = $value unless ($key); # if only one column is selected, then it is both the key and the value
-        $hash{$key} = $value;
+    $self->session->log->query($sql, $params);
+    my $dbh = $self->dbh;
+    my $results = $dbh->selectall_arrayref($sql, {}, @$params);
+    if ($dbh->err) {
+        $self->session->log->fatal("Couldn't execute prepared statement: $sql : With place holders: ".join(", ", @{$params}).".  Root cause: ". $dbh->errstr);
     }
-    $sth->finish;
+    my $width = @{$results} && @{$results->[0]};
+    %hash
+        = $width == 2 ? map { @{ $_ } } @{ $results }
+        # for single column, use it for both key and value
+        : $width == 1 ? map { $_->[0], $_->[0] } @{ $results }
+        : $width == 0 ? ()
+        : map {
+            # for more than 2 columns, use all but last joined with colons for key
+            join( q{:}, @{$_}[ 0 .. ($#{$_} - 1) ] ),
+            # and last column as value
+            $_->[-1]
+        } @{ $results };
     return \%hash;
 }
 
@@ -475,7 +484,7 @@ The value to search for in the key column.
 
 sub deleteRow {
 	my ($self, $table, $key, $keyValue) = @_;
-	my $sth = $self->write("delete from $table where ".$key."=?", [$keyValue]);
+	my $sth = $self->write("delete from ".$self->dbh->quote_identifier($table)." where ".$key."=?", [$keyValue]);
 }
 
 
@@ -597,7 +606,7 @@ The value to search for in the key column.
 
 sub getRow {
         my ($self, $table, $key, $keyValue) = @_;
-        my $row = $self->quickHashRef("select * from $table where ".$key."=?",[$keyValue]);
+        my $row = $self->quickHashRef("select * from ".$self->dbh->quote_identifier($table)." where ".$key."=?",[$keyValue]);
         return $row;
 }
 
@@ -937,7 +946,8 @@ sub setRow {
 	my ($self, $table, $keyColumn, $data, $id) = @_;
 	if ($data->{$keyColumn} eq "new" || $id) {
 		$data->{$keyColumn} = $id || $self->session->id->generate();
-		$self->write("replace into $table (" . $self->dbh->quote_identifier($keyColumn) . ") values (?)",[$data->{$keyColumn}]);
+		$self->write("replace into ".$self->dbh->quote_identifier($table)
+            ." (" . $self->dbh->quote_identifier($keyColumn) . ") values (?)",[$data->{$keyColumn}]);
 	}
 	my @fields = ();
 	my @data = ();
@@ -949,7 +959,7 @@ sub setRow {
 	}
 	if ($fields[0] ne "") {
 		push(@data,$data->{$keyColumn});
-		$self->write("update $table set " . join(", ", @fields)
+		$self->write("update ".$self->dbh->quote_identifier($table)." set " . join(", ", @fields)
             . " where " . $self->dbh->quote_identifier($keyColumn) . "=?", \@data);
 	}
 	return $data->{$keyColumn};
