@@ -193,7 +193,7 @@ sub gateway {
         my $url = $self->session->config->get("gateway").'/'.$pageUrl;
 	$url =~ s/\/+/\//g;
         if ($self->session->setting->get("preventProxyCache") == 1 and !$skipPreventProxyCache) {
-                $url = $self->append($url,"noCache=".randint(0,1000).':'.$self->session->datetime->time());
+                $url = $self->append($url,"noCache=".randint(0,1000).':'.time());
         }
 	if ($pairs) {
 		$url = $self->append($url,$pairs);
