@@ -14,6 +14,7 @@ use WebGUI::Shop::Credit;
 use WebGUI::Shop::Ship;
 use WebGUI::Shop::Tax;
 use WebGUI::User;
+use Tie::IxHash;
 
 =head1 NAME
 
@@ -520,6 +521,9 @@ sub readyForCheckout {
         return 0 if $total < $requiredAmount;
     }
 
+    ##Must have a configured shipping id.
+    return 0 if ! $self->get('shipperId');
+
     ##Check for any other logged errors
     return 0 if $error{ id $self };
 
@@ -772,7 +776,14 @@ sub www_view {
         my $template = WebGUI::Asset::Template->new($session, $session->setting->get("shopCartTemplateId"));
         return $session->style->userStyle($template->process(\%var));
     }
-    
+
+    # get the shipping address    
+    my $address          = eval { $self->getShippingAddress };
+    if (my $e = WebGUI::Error->caught("WebGUI::Error::ObjectNotFound")) {
+        # choose another address cuz we've got a problem
+        $self->update({shippingAddressId=>''});
+    }
+
     # generate template variables for the items in the cart
     foreach my $item (@cartItems) {
         my $sku = $item->getSku;
@@ -790,9 +801,12 @@ sub www_view {
             shipToButton    => WebGUI::Form::submit($session, {value=>$i18n->get("ship to button"), 
                 extras=>q|onclick="setCallbackForAddressChooser(this.form,'|.$item->getId.q|');"|}),
             );
-        my $address = eval {$item->getShippingAddress};
-        unless (WebGUI::Error->caught) {
-            $properties{shippingAddress} = $address->getHtmlFormatted;
+        my $itemAddress = eval {$item->getShippingAddress};
+        if ((!WebGUI::Error->caught) && $itemAddress && $address && $itemAddress->getId ne $address->getId) {
+            $properties{shippingAddress} = $itemAddress->getHtmlFormatted;
+        }
+        else {
+            $properties{shippingAddress} = '';
         }
 
         $taxDriver->appendCartItemVars( \%properties, $item );
@@ -824,45 +838,48 @@ sub www_view {
                                  ,
         );
 
-    # get the shipping address    
-    my $address          = eval { $self->getShippingAddress };
-    if (my $e = WebGUI::Error->caught("WebGUI::Error::ObjectNotFound")) {
-        # choose another address cuz we've got a problem
-        $self->update({shippingAddressId=>''});
-        
-    }
-   
     # if there is no shipping address we can't check out
     if (WebGUI::Error->caught) {
        $var{shippingPrice} = $var{tax} = $self->formatCurrency(0); 
     }
-    
+
     # if there is a shipping address calculate tax and shipping options
-    else {
+    if ($address) {
         $var{hasShippingAddress} = 1;
         $var{shippingAddress} = $address->getHtmlFormatted;
         my $ship = WebGUI::Shop::Ship->new($self->session);
         my $options = $ship->getOptions($self);
-        my %formOptions = ();
-        my $defaultOption = "";
-        foreach my $option (keys %{$options}) {
-            $defaultOption = $option;
-            $formOptions{$option} = $options->{$option}{label}." (".$self->formatCurrency($options->{$option}{price}).")";
-        }
-        if ($defaultOption) {
-            $var{shippingOptions} = WebGUI::Form::selectBox($session, {name=>"shipperId", options=>\%formOptions, defaultValue=>$defaultOption, value=>$self->get("shipperId")});
-            if (! exists $options->{ $self->get('shipperId') }) {
-                $self->update({shipperId => ''});
-            }
-            $var{shippingPrice} = ($self->get("shipperId") ne "") ? $options->{$self->get("shipperId")}{price} : $options->{$defaultOption}{price};
-            $var{shippingPrice} = $self->formatCurrency($var{shippingPrice});
-        }
-        else {
+        my $numberOfOptions = scalar keys %{ $options };
+        if ($numberOfOptions < 1) {
             $var{shippingOptions} = '';
             $var{shippingPrice}   = 0;
             $error{id $self}      = $i18n->get("No shipping plugins configured");
         }
-
+        elsif ($numberOfOptions == 1) {
+            my ($option) = keys %{ $options };
+            $self->update({ shipperId => $option });
+            $var{shippingPrice} = $options->{$self->get("shipperId")}->{price};
+            $var{shippingPrice} = $self->formatCurrency($var{shippingPrice});
+        }
+        else {
+            tie my %formOptions, 'Tie::IxHash';
+            $formOptions{''} = $i18n->get('Choose a shipping method');
+            foreach my $option (keys %{$options}) {
+                $formOptions{$option} = $options->{$option}{label}." (".$self->formatCurrency($options->{$option}{price}).")";
+            }
+            $var{shippingOptions} = WebGUI::Form::selectBox($session, {name=>"shipperId", options=>\%formOptions, value=>$self->get("shipperId")});
+            if (!exists $options->{$self->get('shipperId')}) {
+                $self->update({shipperId => ''});
+            }
+            if (my $shipperId = $self->get('shipperId')) {
+                $var{shippingPrice} = $options->{$shipperId}->{price};
+            }
+            else {
+                $var{shippingPrice} = 0;
+                $error{id $self}    = ($i18n->get('Choose a shipping method and update the cart to checkout'));
+            }
+            $var{shippingPrice} = $self->formatCurrency($var{shippingPrice});
+        }
     }
   
     # Tax variables
@@ -881,7 +898,7 @@ sub www_view {
     $var{totalPrice} = $var{subtotalPrice} + $var{shippingPrice} + $var{tax};
     my $credit = WebGUI::Shop::Credit->new($session, $posUser->userId);
     $var{ inShopCreditAvailable } = $credit->getSum;
-    $var{ inShopCreditDeduction } = $credit->calculateDeduction($var{totalPrice});
+    $var{ inShopCreditDeduction } = $self->calculateShopCreditDeduction($var{totalPrice});
     $var{ totalPrice            } = $self->formatCurrency($var{totalPrice} + $var{inShopCreditDeduction});
     $var{ readyForCheckout      } = $self->readyForCheckout;
     $var{ error                 } = $error{id $self}; 
