@@ -137,7 +137,7 @@ sub create {
 	my $properties = shift;
 	my $tagId = $session->db->setRow("assetVersionTag","tagId",{
 		tagId=>"new",
-		creationDate=>$session->datetime->time(),
+		creationDate=>time(),
 		createdBy=>$session->user->userId
 		});
 	my $tag = $class->new($session, $tagId);
@@ -178,7 +178,7 @@ sub commit {
 	if ($finished) {
 		$self->{_data}{isCommitted} = 1;
 		$self->{_data}{committedBy} = $self->session->user->userId unless ($self->{_data}{committedBy});
-		$self->{_data}{commitDate} = $self->session->datetime->time();
+		$self->{_data}{commitDate} = time();
 		$self->session->db->setRow("assetVersionTag", "tagId", $self->{_data});
 		$self->clearWorking;
 		return 1;
@@ -630,6 +630,10 @@ sub rollback {
         $outputSub->(sprintf $i18n->get('Rolling back %s'), $revision->getTitle);
 		$revision->purgeRevision;
 	}
+    my $instance = $self->getWorkflowInstance;
+    if ($instance) {
+        $instance->delete;
+    }
 	$session->db->write("delete from assetVersionTag where tagId=?", [$tagId]);
 	$self->clearWorking;
 	return 1;
@@ -688,7 +692,7 @@ sub set {
     my $self = shift;
     my $properties = shift;
 
-    my $now        = $self->session->datetime->time();
+    my $now        = time();
     my $startTime  = WebGUI::DateTime->new($self->session,$now)->toDatabase;
     my $endTime    = WebGUI::DateTime->new($self->session,'2036-01-01 00:00:00')->toDatabase;
 
