@@ -1185,10 +1185,8 @@ submitted by a user.|,
         },
 
         'sort by description' => {
-                message => q|By default, all posts are displayed in a sorted order.  Use this
-field to choose by what property they are sorted.  Multiple properties
-may be selected.|,
-                lastUpdated => 1119070429,
+                message => q|By default, all posts are displayed in a sorted order.  Use this field to choose by what property they are sorted.|,
+                lastUpdated => 1275922704,
         },
 
         'sort order description' => {
@@ -1671,6 +1669,18 @@ the Collaboration Asset, the user will be notified.|,
         lastUpdated => 1229910435,
     },
 
+    'unarchive all' => {
+        message     => q{Unarchive All Threads},
+        context     => q{Label for link to unarchive all threads},
+        lastUpdated => 0,
+    },
+
+    'unarchive confirm' => {
+        message     => q{Are you sure? Any threads past the 'Archive After' interval will be re-archived.},
+        context     => q{Text for pop-up dialog to confirm unarchive all threads},
+        lastUpdated => 0,
+    },
+
 };
 
 1;
