@@ -29,12 +29,12 @@ our $I18N = {
     },
 
     'add photo' => {
-        message     => '<li><a href="%s">Add Photo</a></li>',
+        message     => 'Add Photo',
         lastUpdated => 0,
     },
 
     'return to album' => {
-        message     => '<li><a href="%s">Return to Album</a></li>',
+        message     => 'Return to Album',
         lastUpdated => 0,
     },
 
@@ -597,6 +597,36 @@ our $I18N = {
         context     => 'Label for URL to add an album Description.',
     },
 
+    'Uploading archive' => {
+        message     => 'Uploading archive',
+        lastUpdated => 1237403498,
+        context     => 'label for progress bar in addArchive',
+    },
+
+    'Extracting archive' => {
+        message     => 'Extracting archive',
+        lastUpdated => 1237403498,
+        context     => 'label for progress bar in addArchive',
+    },
+
+    'Found file: %s' => {
+        message     => 'Found file %s',
+        lastUpdated => 1237403498,
+        context     => 'label for progress bar in addArchive',
+    },
+
+    'Adding %s to album' => {
+        message     => 'Adding %s to album',
+        lastUpdated => 1237403498,
+        context     => 'label for progress bar in addArchive',
+    },
+
+    'Requesting commit for version tag' => {
+        message     => 'Requesting commit for version tag',
+        lastUpdated => 1237403498,
+        context     => 'label for progress bar in addArchive',
+    },
+
 };
 
 1;
