@@ -273,6 +273,66 @@ our $I18N =
                 lastUpdated => 1169141075,
         },
 
+    'help isSubscribed' => {
+        message     => q{This variable is true if the user is subscribed to this wiki page},
+        lastUpdated => 0,
+        context     => q{Help for template variable},
+    },
+
+    'help subscribeUrl' => {
+        message     => q{The URL to subscribe to this wiki page},
+        lastUpdated => 0,
+        context     => q{Help for template variable},
+    },
+
+    'help unsubscribeUrl' => {
+        message     => q{The URL to unsubscribe from this wiki page},
+        lastUpdated => 0,
+        context     => q{Help for template variable},
+    },
+
+    'keywordsLoop' => {
+        message     => q{A loop containing all keywords for this page is tagged with.},
+        lastUpdated => 0,
+        context     => q{Help for template variable},
+    },
+
+    'keyword title' => {
+        message     => q{The name of this keyword.},
+        lastUpdated => 0,
+        context     => q{Help for template variable},
+    },
+
+    'keyword url' => {
+        message     => q{The URL to view all pages tagged with this keyword.},
+        lastUpdated => 0,
+        context     => q{Help for template variable},
+    },
+
+    'help owner' => {
+        message     => q{The username of the owner of the page},
+        lastUpdated => 0,
+        context     => q{Help for template variable},
+    },
+
+    'help subscription title' => {
+        message     => q{Wiki Page Subscription E-mail},
+        lastUpdated => 0,
+        context     => 'Title for help page',
+    },
+
+    'help subscription body' => {
+        message     => q{The template to send via e-mail to the people subscribed to the wiki},
+        lastUpdated => 0,
+        context     => 'Body text for help page',
+    },
+
+
+    'isFeatured label' => {
+        message     => q{Feature this on the front page},
+        lastUpdated => 0,
+        context     => 'Label for asset property',
+    },
 };
 
 1;
