@@ -88,6 +88,7 @@ checkModule("DateTime",                     0.4501       );
 checkModule("Time::HiRes",                  1.9719       );
 checkModule("DateTime::Format::Strptime",   1.0800       );
 checkModule("DateTime::Format::Mail",       0.3001       );
+checkModule("DateTime::Format::HTTP",       0.38         );
 checkModule("Image::Magick",                "6.0"        );
 checkModule("Log::Log4perl",                1.20         );
 checkModule("Net::LDAP",                    0.39         );
@@ -100,8 +101,7 @@ checkModule("XML::FeedPP",                  0.40         );
 checkModule("JSON",                         2.12         );
 checkModule("Config::JSON",                 "1.3.1"      );
 checkModule("Text::CSV_XS",                 "0.64"       );
-checkModule("Net::Subnets",                 0.21         );
-checkModule("Net::CIDR::Lite",              0.20,      2 );
+checkModule("Net::CIDR::Lite",              0.20         );
 checkModule("Finance::Quote",               1.15         );
 checkModule("POE",                          1.005        );
 checkModule("POE::Component::IKC::Server",  0.2001       );
@@ -126,7 +126,7 @@ checkModule("Class::C3",                    "0.21"       );
 checkModule("Params::Validate",             "0.91"       );
 checkModule("Clone",                        "0.31"       );
 checkModule('HTML::Packer',                 "0.4"        );
-checkModule('JavaScript::Packer',           '0.02'       );
+checkModule('JavaScript::Packer',           '0.04'       );
 checkModule('CSS::Packer',                  '0.2'        );
 checkModule('Business::Tax::VAT::Validation', '0.20'     );
 checkModule('Crypt::SSLeay',                '0.57'       );
@@ -135,6 +135,9 @@ checkModule('Digest::SHA',                  '5.47'       );
 checkModule("CSS::Minifier::XS",            "0.03"       );
 checkModule("JavaScript::Minifier::XS",     "0.05"       );
 checkModule("Readonly",                     "1.03"       );
+checkModule("Business::PayPal::API",        "0.62"       );
+checkModule("Locales",                      "0.10"       );
+checkModule('IO::Socket::SSL',                           );
 
 failAndExit("Required modules are missing, running no more checks.") if $missingModule;
 
