@@ -92,7 +92,7 @@ while(my $line = <FILE>) {
     next
         if $line eq '';
     my @row = split($delimiter, $line);
-    #use Data::Dumper;
+    use Data::Dumper ();
     chomp @row;
     if ($lineNumber == 1) {
         @field = @row;
@@ -213,7 +213,7 @@ sub calculateExpireOffset {
         }
     }
     if ($units eq "fixed") {
-        my $seconds = (($offset - $session->datetime->time()));
+        my $seconds = (($offset - time()));
         if ($seconds < 1) {
             return undef;
         }
@@ -272,21 +272,13 @@ names are:
 =over
 
 =item B<username>
-
 =item B<password>
-
 =item B<authMethod>
-
 =item B<status>
-
 =item B<ldapUrl>
-
 =item B<connectDN>
-
 =item B<groups>
-
 =item B<expireOffset>
-
 =item Any valid User Profile field name available in WebGUI's database,
       e.g. B<firstName>, B<lastName>, B<mail>, etc.
 
@@ -370,7 +362,7 @@ It can be overridden in the import file for specific users.
 =item B<--identifier string>
 
 Specify the default password to use for loaded users. It can (and should)
-be overriden in the import file for specific users. If left unspecified,
+be overridden in the import file for specific users. If left unspecified,
 it defaults to B<123qwe>.
 
 =item B<--status status>
