@@ -112,6 +112,7 @@ sub import {
             Transactions        => 'transaction',
             'Transaction Items' => 'transactionItem',
             'Ship Drivers'      => 'shipper',
+            'Payment Drivers'   => 'paymentGateway',
             'Database Links'    => 'databaseLink',
             'LDAP Links'        => 'ldapLink',
         );
@@ -152,6 +153,8 @@ sub cleanup {
     }
 }
 
+#----------------------------------------------------------------------------
+
 =head2 newSession ( $noCleanup )
 
 Builds a WebGUI session object for testing.
@@ -162,8 +165,6 @@ If true, the session won't be registered for automatic deletion.
 
 =cut
 
-#----------------------------------------------------------------------------
-
 sub newSession {
     my $noCleanup = shift;
     my $pseudoRequest = WebGUI::PseudoRequest->new;
@@ -176,6 +177,8 @@ sub newSession {
 }
 
 
+#----------------------------------------------------------------------------
+
 =head2 mockAssetId ( $assetId, $object )
 
 Causes WebGUI::Asset->new* initializers to return the specified
@@ -505,11 +508,11 @@ Returns a hashref of properties for connecting to smoke's LDAP server.
 sub getSmokeLDAPProps {
     my $ldapProps   = {
         ldapLinkName    => "Test LDAP Link",
-        ldapUrl         => "ldaps://smoke.plainblack.com/ou=Convicts,o=shawshank", # Always test ldaps
-        connectDn       => "cn=Samuel Norton,ou=Warden,o=shawshank",
+        ldapUrl         => "ldaps://smoke.plainblack.com/o=shawshank", # Always test ldaps
+        connectDn       => "cn=Warden,o=shawshank",
         identifier      => "gooey",
         ldapUserRDN     => "dn",
-        ldapIdentity    => "cn",
+        ldapIdentity    => "uid",
         ldapLinkId      => sprintf( '%022s', "testlink" ),
     };
     return $ldapProps;
@@ -790,9 +793,11 @@ were passed in.  Currently able to destroy:
     WebGUI::Workflow
     WebGUI::Shop::Cart
     WebGUI::Shop::ShipDriver
+    WebGUI::Shop::PayDriver
     WebGUI::Shop::Transaction
     WebGUI::DatabaseLink
     WebGUI::LDAPLink
+    WebGUI::Inbox::Message
 
 Example call:
 
@@ -815,6 +820,10 @@ Example call:
             my ($class, $ident) = @_;
             return WebGUI::Storage->get($CLASS->session, $ident);
         },
+        'SQL' => sub {
+            my (undef, $sql) = @_;
+            return $CLASS->session->db->dbh->prepare($sql);
+        },
     );
 
     my %clone = (
@@ -875,6 +884,8 @@ Example call:
         'WebGUI::DatabaseLink'      => 'delete',
         'WebGUI::Shop::Transaction' => 'delete',
         'WebGUI::Shop::ShipDriver'  => 'delete',
+        'WebGUI::Shop::PayDriver'   => 'delete',
+        'WebGUI::Inbox::Message'     => 'purge',
         'WebGUI::Shop::Cart'        => sub {
             my $cart        = shift;
             my $addressBook = $cart->getAddressBook();
@@ -890,6 +901,10 @@ Example call:
             my $link = shift;
             $link->session->db->write("delete from ldapLink where ldapLinkId=?", [$link->{ldapLinkId}]);
         },
+        'CODE' => sub {
+            (shift)->();
+        },
+        'SQL' => 'execute',
     );
 
     sub cleanupGuard {
@@ -901,9 +916,9 @@ Example call:
             my $construct;
             if ( ref $class ) {
                 my $object = $class;
+                $class = ref $class;
                 my $cloneSub = $CLASS->_findByIsa($class, \%clone);
                 $construct = $cloneSub ? sub { $object->$cloneSub } : sub { $object };
-                $class = ref $class;
             }
             else {
                 my $id = shift;
@@ -953,7 +968,7 @@ sub _findByIsa {
     my $toFind = shift;
     my $hash = shift;
     for my $key ( sort { length $b <=> length $a} keys %$hash ) {
-        if ($toFind->isa($key)) {
+        if ($toFind eq $key || $toFind->isa($key)) {
             return $hash->{$key};
         }
     }
